package cn.leancloud;

import cn.leancloud.annotation.AVClassName;
import cn.leancloud.cache.PersistenceUtil;
import cn.leancloud.codec.MD5;
import cn.leancloud.core.AVOSCloud;
import cn.leancloud.core.AppConfiguration;
import cn.leancloud.utils.LogUtil;
import cn.leancloud.utils.StringUtil;
import java.io.File;
import java.util.TimeZone;
import java.util.UUID;

@AVClassName(AVInstallation.CLASS_NAME)
public final class AVInstallation extends AVObject {
    private static final String CHANNELSTAG = "channel";
    public static final String CLASS_NAME = "_Installation";
    private static String DEFAULT_DEVICETYPE = "android";
    private static final String DEVICETYPETAG = "deviceType";
    static final String INSTALLATION = "installation";
    private static final String INSTALLATIONIDTAG = "installationId";
    private static final AVLogger LOGGER = LogUtil.getLogger(AVInstallation.class);
    public static final String REGISTRATION_ID = "registrationId";
    private static final String TIMEZONE = "timeZone";
    public static final String VENDOR = "vendor";
    private static volatile AVInstallation currentInstallation;

    AVInstallation() {
        super(CLASS_NAME);
        this.totallyOverwrite = true;
        initialize();
        this.endpointClassName = "installations";
    }

    protected AVInstallation(AVObject aVObject) {
        this.objectId = aVObject.getObjectId();
        this.acl = aVObject.getACL();
        this.serverData = aVObject.getServerData();
        this.totallyOverwrite = true;
        this.endpointClassName = "installations";
    }

    public static AVInstallation getCurrentInstallation() {
        if (currentInstallation == null) {
            synchronized (AVInstallation.class) {
                if (currentInstallation == null) {
                    currentInstallation = createInstanceFromLocal(INSTALLATION);
                }
            }
        }
        return currentInstallation;
    }

    private static File getCacheFile() {
        String importantFileDir = AppConfiguration.getImportantFileDir();
        if (StringUtil.isEmpty(importantFileDir)) {
            return null;
        }
        return new File(importantFileDir, AVOSCloud.getSimplifiedAppId() + INSTALLATION);
    }

    protected static AVInstallation createInstanceFromLocal(String str) {
        File cacheFile = getCacheFile();
        String genInstallationId = genInstallationId();
        if (cacheFile != null) {
            AVLogger aVLogger = LOGGER;
            aVLogger.d("installation cache file path: " + cacheFile.getAbsolutePath());
            if (!cacheFile.exists()) {
                File file = new File(AppConfiguration.getImportantFileDir(), INSTALLATION);
                if (file.exists() && !file.renameTo(cacheFile)) {
                    aVLogger.w("failed to rename installation cache file.");
                }
            }
            if (cacheFile.exists()) {
                String readContentFromFile = PersistenceUtil.sharedInstance().readContentFromFile(cacheFile);
                if (StringUtil.isEmpty(readContentFromFile)) {
                    aVLogger.d("installation cache file is empty, create new instance.");
                } else if (readContentFromFile.indexOf("{") >= 0) {
                    try {
                        currentInstallation = (AVInstallation) AVObject.parseAVObject(readContentFromFile);
                        currentInstallation.totallyOverwrite = true;
                    } catch (Exception e) {
                        LOGGER.w("failed to parse local installation data.", e);
                    }
                } else if (readContentFromFile.length() == UUID_LEN) {
                    genInstallationId = readContentFromFile;
                }
            }
        }
        if (currentInstallation == null) {
            String format = String.format("{ \"_version\":\"5\",\"className\":\"_Installation\",\"serverData\":{\"@type\":\"java.util.concurrent.ConcurrentHashMap\",\"deviceType\":\"android\",\"installationId\":\"%s\",\"timeZone\":\"%s\"}}", genInstallationId, timezone());
            PersistenceUtil.sharedInstance().saveContentToFile(format, cacheFile);
            AVLogger aVLogger2 = LOGGER;
            aVLogger2.d("create-ahead installation with json: " + format);
            try {
                currentInstallation = (AVInstallation) AVObject.parseAVObject(format);
                currentInstallation.totallyOverwrite = true;
            } catch (Exception e2) {
                LOGGER.w("failed to parse create-ahead installation string.", e2);
                currentInstallation = new AVInstallation();
                currentInstallation.setInstallationId(genInstallationId);
            }
        }
        return currentInstallation;
    }

    public static void changeDeviceType(String str) {
        DEFAULT_DEVICETYPE = str;
    }

    private static String deviceType() {
        return DEFAULT_DEVICETYPE;
    }

    private static String timezone() {
        return TimeZone.getDefault().getID();
    }

    private void initialize() {
        if (currentInstallation != null) {
            put(INSTALLATIONIDTAG, currentInstallation.getInstallationId());
        } else {
            String genInstallationId = genInstallationId();
            if (!StringUtil.isEmpty(genInstallationId)) {
                put(INSTALLATIONIDTAG, genInstallationId);
            }
        }
        put(DEVICETYPETAG, deviceType());
        put(TIMEZONE, timezone());
    }

    private static String genInstallationId() {
        String applicationPackageName = AppConfiguration.getApplicationPackageName();
        String uuid = UUID.randomUUID().toString();
        return MD5.computeMD5(applicationPackageName + uuid);
    }

    public String getInstallationId() {
        return getString(INSTALLATIONIDTAG);
    }

    public static AVQuery<AVInstallation> getQuery() {
        return new AVQuery<>(CLASS_NAME);
    }

    /* access modifiers changed from: protected */
    @Override // cn.leancloud.AVObject
    public void onSaveSuccess() {
        super.onSaveSuccess();
        updateCurrentInstallationCache();
    }

    /* access modifiers changed from: protected */
    @Override // cn.leancloud.AVObject
    public void onDataSynchronized() {
        super.onDataSynchronized();
        updateCurrentInstallationCache();
    }

    /* access modifiers changed from: package-private */
    public void updateCurrentInstallationCache() {
        if (currentInstallation == this) {
            File cacheFile = getCacheFile();
            PersistenceUtil.sharedInstance().saveContentToFile(currentInstallation.toJSONString(), cacheFile);
        }
    }

    /* access modifiers changed from: package-private */
    public void setInstallationId(String str) {
        put(INSTALLATIONIDTAG, str);
    }
}
