package cn.leancloud;

import cn.leancloud.core.AVOSCloud;
import cn.leancloud.core.AppConfiguration;
import cn.leancloud.core.PaasClient;
import cn.leancloud.network.NetworkingDetector;
import cn.leancloud.ops.BaseOperation;
import cn.leancloud.ops.CompoundOperation;
import cn.leancloud.ops.ObjectFieldOperation;
import cn.leancloud.ops.OperationBuilder;
import cn.leancloud.ops.Utils;
import cn.leancloud.types.AVDate;
import cn.leancloud.types.AVGeoPoint;
import cn.leancloud.types.AVNull;
import cn.leancloud.utils.AVUtils;
import cn.leancloud.utils.LogUtil;
import cn.leancloud.utils.StringUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.annotation.JSONType;
import com.alibaba.fastjson.parser.Feature;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.umeng.analytics.pro.b;
import io.reactivex.Observable;
import io.reactivex.ObservableSource;
import io.reactivex.Observer;
import io.reactivex.disposables.Disposable;
import io.reactivex.functions.Function;
import io.reactivex.schedulers.Schedulers;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.Set;
import java.util.TreeSet;
import java.util.UUID;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;
import java.util.regex.Pattern;

@JSONType(deserializer = ObjectTypeAdapter.class, serializer = ObjectTypeAdapter.class)
public class AVObject {
    private static final String INTERNAL_PATTERN = "^[\\da-z][\\d-a-z]*$";
    public static final String KEY_ACL = "ACL";
    public static final String KEY_CLASSNAME = "className";
    public static final String KEY_CREATED_AT = "createdAt";
    public static final String KEY_IGNORE_HOOKS = "__ignore_hooks";
    public static final String KEY_OBJECT_ID = "objectId";
    public static final String KEY_UPDATED_AT = "updatedAt";
    private static final Set<String> RESERVED_ATTRS = new HashSet(Arrays.asList(KEY_CREATED_AT, KEY_UPDATED_AT, KEY_OBJECT_ID, KEY_ACL));
    protected static final int UUID_LEN = UUID.randomUUID().toString().length();
    protected static final AVLogger logger = LogUtil.getLogger(AVObject.class);
    protected AVACL acl;
    protected String className;
    protected String endpointClassName;
    @JSONField(serialize = false)
    private volatile boolean fetchWhenSave;
    @JSONField(serialize = false)
    private Set<Hook> ignoreHooks;
    protected String objectId;
    protected ConcurrentMap<String, ObjectFieldOperation> operations;
    protected ConcurrentMap<String, Object> serverData;
    protected volatile boolean totallyOverwrite;
    private String uuid;

    public enum Hook {
        beforeSave,
        afterSave,
        beforeUpdate,
        afterUpdate,
        beforeDelete,
        afterDelete
    }

    /* access modifiers changed from: protected */
    public void onDataSynchronized() {
    }

    /* access modifiers changed from: protected */
    public void onSaveFailure() {
    }

    public AVObject() {
        this.endpointClassName = null;
        this.objectId = "";
        this.serverData = new ConcurrentHashMap();
        this.operations = new ConcurrentHashMap();
        this.acl = null;
        this.uuid = null;
        this.fetchWhenSave = false;
        this.totallyOverwrite = false;
        this.ignoreHooks = new TreeSet();
        this.className = Transformer.getSubClassName(getClass());
    }

    public AVObject(String str) {
        this.endpointClassName = null;
        this.objectId = "";
        this.serverData = new ConcurrentHashMap();
        this.operations = new ConcurrentHashMap();
        this.acl = null;
        this.uuid = null;
        this.fetchWhenSave = false;
        this.totallyOverwrite = false;
        this.ignoreHooks = new TreeSet();
        Transformer.checkClassName(str);
        this.className = str;
    }

    public AVObject(AVObject aVObject) {
        this.endpointClassName = null;
        this.objectId = "";
        this.serverData = new ConcurrentHashMap();
        this.operations = new ConcurrentHashMap();
        this.acl = null;
        this.uuid = null;
        this.fetchWhenSave = false;
        this.totallyOverwrite = false;
        this.ignoreHooks = new TreeSet();
        this.className = aVObject.className;
        this.objectId = aVObject.objectId;
        this.serverData.putAll(aVObject.serverData);
        this.operations.putAll(aVObject.operations);
        this.acl = aVObject.acl;
        this.endpointClassName = aVObject.endpointClassName;
    }

    public String getClassName() {
        return this.className;
    }

    public String internalClassName() {
        return getClassName();
    }

    public void setClassName(String str) {
        Transformer.checkClassName(str);
        this.className = str;
    }

    public Date getCreatedAt() {
        return StringUtil.dateFromString(getCreatedAtString());
    }

    public String getCreatedAtString() {
        return (String) this.serverData.get(KEY_CREATED_AT);
    }

    public Date getUpdatedAt() {
        return StringUtil.dateFromString(getUpdatedAtString());
    }

    public String getUpdatedAtString() {
        return (String) this.serverData.get(KEY_UPDATED_AT);
    }

    public String getObjectId() {
        if (this.serverData.containsKey(KEY_OBJECT_ID)) {
            return (String) this.serverData.get(KEY_OBJECT_ID);
        }
        return this.objectId;
    }

    public void setObjectId(String str) {
        this.objectId = str;
        if (this.serverData != null && !StringUtil.isEmpty(str)) {
            this.serverData.put(KEY_OBJECT_ID, str);
        }
    }

    public boolean isFetchWhenSave() {
        return this.fetchWhenSave;
    }

    public void setFetchWhenSave(boolean z) {
        this.fetchWhenSave = z;
    }

    public String getUuid() {
        if (StringUtil.isEmpty(this.uuid)) {
            this.uuid = UUID.randomUUID().toString().toLowerCase();
        }
        return this.uuid;
    }

    /* access modifiers changed from: package-private */
    public void setUuid(String str) {
        this.uuid = str;
    }

    protected static boolean verifyInternalId(String str) {
        return Pattern.matches(INTERNAL_PATTERN, str);
    }

    /* access modifiers changed from: protected */
    public String internalId() {
        return StringUtil.isEmpty(getObjectId()) ? getUuid() : getObjectId();
    }

    public boolean containsKey(String str) {
        return this.serverData.containsKey(str);
    }

    public boolean has(String str) {
        return get(str) != null;
    }

    public Object get(String str) {
        Object obj = this.serverData.get(str);
        ObjectFieldOperation objectFieldOperation = this.operations.get(str);
        return objectFieldOperation != null ? objectFieldOperation.apply(obj) : obj;
    }

    public boolean getBoolean(String str) {
        Boolean bool = (Boolean) get(str);
        if (bool == null) {
            return false;
        }
        return bool.booleanValue();
    }

    public byte[] getBytes(String str) {
        return (byte[]) get(str);
    }

    public Date getDate(String str) {
        Object obj = get(str);
        if (obj instanceof Date) {
            return (Date) obj;
        }
        if (obj instanceof Long) {
            return new Date(((Long) obj).longValue());
        }
        if (obj instanceof String) {
            return StringUtil.dateFromString((String) obj);
        }
        if (obj instanceof JSONObject) {
            return new AVDate((JSONObject) obj).getDate();
        }
        if (obj instanceof Map) {
            return new AVDate(new JSONObject((Map) obj)).getDate();
        }
        return null;
    }

    public String getString(String str) {
        Object obj = get(str);
        if (obj instanceof String) {
            return (String) obj;
        }
        return null;
    }

    public int getInt(String str) {
        Number number = (Number) get(str);
        if (number != null) {
            return number.intValue();
        }
        return 0;
    }

    public long getLong(String str) {
        Number number = (Number) get(str);
        if (number != null) {
            return number.longValue();
        }
        return 0;
    }

    public double getDouble(String str) {
        Number number = (Number) get(str);
        if (number != null) {
            return number.doubleValue();
        }
        return 0.0d;
    }

    public Number getNumber(String str) {
        return (Number) get(str);
    }

    public List getList(String str) {
        return (List) get(str);
    }

    public JSONArray getJSONArray(String str) {
        Object obj = get(str);
        JSONArray jSONArray = null;
        if (obj == null) {
            return null;
        }
        if (obj instanceof JSONArray) {
            return (JSONArray) obj;
        }
        if (obj instanceof List) {
            return new JSONArray((List) obj);
        }
        if (obj instanceof Object[]) {
            jSONArray = new JSONArray();
            for (Object obj2 : (Object[]) obj) {
                jSONArray.add(obj2);
            }
        }
        return jSONArray;
    }

    public JSONObject getJSONObject(String str) {
        Object obj = get(str);
        if (obj instanceof JSONObject) {
            return (JSONObject) obj;
        }
        try {
            return JSON.parseObject(JSON.toJSONString(obj));
        } catch (Exception e) {
            throw new IllegalStateException("Invalid json string", e);
        }
    }

    public AVGeoPoint getAVGeoPoint(String str) {
        return (AVGeoPoint) get(str);
    }

    public AVFile getAVFile(String str) {
        return (AVFile) get(str);
    }

    public <T extends AVObject> T getAVObject(String str) {
        try {
            return (T) ((AVObject) get(str));
        } catch (Exception e) {
            logger.w("failed to convert Object.", e);
            return null;
        }
    }

    public <T extends AVObject> AVRelation<T> getRelation(String str) {
        validFieldName(str);
        Object obj = get(str);
        if (!(obj instanceof AVRelation)) {
            return new AVRelation<>(this, str);
        }
        AVRelation<T> aVRelation = (AVRelation) obj;
        aVRelation.setParent(this);
        aVRelation.setKey(str);
        return aVRelation;
    }

    /* access modifiers changed from: package-private */
    public void addRelation(AVObject aVObject, String str) {
        validFieldName(str);
        addNewOperation(OperationBuilder.gBuilder.create(OperationBuilder.OperationType.AddRelation, str, aVObject));
    }

    /* access modifiers changed from: package-private */
    public void removeRelation(AVObject aVObject, String str) {
        validFieldName(str);
        addNewOperation(OperationBuilder.gBuilder.create(OperationBuilder.OperationType.RemoveRelation, str, aVObject));
    }

    public ConcurrentMap<String, Object> getServerData() {
        return this.serverData;
    }

    /* access modifiers changed from: protected */
    public void validFieldName(String str) {
        if (StringUtil.isEmpty(str)) {
            throw new IllegalArgumentException("Blank key");
        } else if (str.startsWith("_")) {
            throw new IllegalArgumentException("key should not start with '_'");
        } else if (RESERVED_ATTRS.contains(str)) {
            throw new IllegalArgumentException("key(" + str + ") is reserved by LeanCloud");
        }
    }

    @JSONField(serialize = false)
    public boolean isDataAvailable() {
        return !StringUtil.isEmpty(this.objectId) && !this.serverData.isEmpty();
    }

    public void add(String str, Object obj) {
        validFieldName(str);
        addNewOperation(OperationBuilder.gBuilder.create(OperationBuilder.OperationType.Add, str, obj));
    }

    public void addAll(String str, Collection<?> collection) {
        validFieldName(str);
        addNewOperation(OperationBuilder.gBuilder.create(OperationBuilder.OperationType.Add, str, collection));
    }

    public void addUnique(String str, Object obj) {
        validFieldName(str);
        addNewOperation(OperationBuilder.gBuilder.create(OperationBuilder.OperationType.AddUnique, str, obj));
    }

    public void addAllUnique(String str, Collection<?> collection) {
        validFieldName(str);
        addNewOperation(OperationBuilder.gBuilder.create(OperationBuilder.OperationType.AddUnique, str, collection));
    }

    public void put(String str, Object obj) {
        validFieldName(str);
        addNewOperation(OperationBuilder.gBuilder.create(OperationBuilder.OperationType.Set, str, obj));
    }

    public void remove(String str) {
        validFieldName(str);
        addNewOperation(OperationBuilder.gBuilder.create(OperationBuilder.OperationType.Delete, str, null));
    }

    public void removeAll(String str, Collection<?> collection) {
        validFieldName(str);
        addNewOperation(OperationBuilder.gBuilder.create(OperationBuilder.OperationType.Remove, str, collection));
    }

    public void increment(String str) {
        increment(str, 1);
    }

    public void increment(String str, Number number) {
        validFieldName(str);
        addNewOperation(OperationBuilder.gBuilder.create(OperationBuilder.OperationType.Increment, str, number));
    }

    public void decrement(String str) {
        decrement(str, 1);
    }

    public void decrement(String str, Number number) {
        validFieldName(str);
        addNewOperation(OperationBuilder.gBuilder.create(OperationBuilder.OperationType.Decrement, str, number));
    }

    public void bitAnd(String str, long j) {
        validFieldName(str);
        addNewOperation(OperationBuilder.gBuilder.create(OperationBuilder.OperationType.BitAnd, str, Long.valueOf(j)));
    }

    public void bitOr(String str, long j) {
        validFieldName(str);
        addNewOperation(OperationBuilder.gBuilder.create(OperationBuilder.OperationType.BitOr, str, Long.valueOf(j)));
    }

    public void bitXor(String str, long j) {
        validFieldName(str);
        addNewOperation(OperationBuilder.gBuilder.create(OperationBuilder.OperationType.BitXor, str, Long.valueOf(j)));
    }

    public void abortOperations() {
        if (this.totallyOverwrite) {
            logger.w("Can't abort modify operations under TotalOverWrite mode.");
        }
        this.operations.clear();
    }

    /* access modifiers changed from: protected */
    public void addNewOperation(ObjectFieldOperation objectFieldOperation) {
        if (objectFieldOperation != null) {
            if (!this.totallyOverwrite) {
                ObjectFieldOperation objectFieldOperation2 = null;
                if (this.operations.containsKey(objectFieldOperation.getField())) {
                    objectFieldOperation2 = this.operations.get(objectFieldOperation.getField());
                }
                this.operations.put(objectFieldOperation.getField(), objectFieldOperation.merge(objectFieldOperation2));
            } else if ("Delete".equalsIgnoreCase(objectFieldOperation.getOperation())) {
                this.serverData.remove(objectFieldOperation.getField());
            } else {
                Object apply = objectFieldOperation.apply(this.serverData.get(objectFieldOperation.getField()));
                if (apply == null) {
                    this.serverData.remove(objectFieldOperation.getField());
                } else {
                    this.serverData.put(objectFieldOperation.getField(), apply);
                }
            }
        }
    }

    private boolean needBatchMode() {
        for (ObjectFieldOperation objectFieldOperation : this.operations.values()) {
            if (objectFieldOperation instanceof CompoundOperation) {
                return true;
            }
        }
        return false;
    }

    /* access modifiers changed from: protected */
    public JSONObject generateChangedParam() {
        List<Map<String, Object>> encodeRestOp;
        if (this.totallyOverwrite) {
            HashMap hashMap = new HashMap();
            for (Map.Entry<String, Object> entry : this.serverData.entrySet()) {
                hashMap.put(entry.getKey(), BaseOperation.encodeObject(entry.getValue()));
            }
            hashMap.remove(KEY_CREATED_AT);
            hashMap.remove(KEY_UPDATED_AT);
            hashMap.remove(KEY_OBJECT_ID);
            if (this.ignoreHooks.size() > 0) {
                hashMap.put(KEY_IGNORE_HOOKS, this.ignoreHooks);
            }
            return new JSONObject(hashMap);
        }
        HashMap hashMap2 = new HashMap();
        for (Map.Entry<String, ObjectFieldOperation> entry2 : this.operations.entrySet()) {
            hashMap2.putAll(entry2.getValue().encode());
        }
        if (this.acl != null) {
            if (!this.acl.equals(generateACLFromServerData())) {
                hashMap2.putAll(OperationBuilder.gBuilder.create(OperationBuilder.OperationType.Set, KEY_ACL, this.acl).encode());
            }
        }
        if (this.ignoreHooks.size() > 0) {
            hashMap2.put(KEY_IGNORE_HOOKS, this.ignoreHooks);
        }
        if (!needBatchMode()) {
            return new JSONObject(hashMap2);
        }
        ArrayList arrayList = new ArrayList();
        Map<String, Object> makeCompletedRequest = Utils.makeCompletedRequest(getObjectId(), getRequestRawEndpoint(), getRequestMethod(), hashMap2);
        if (makeCompletedRequest != null) {
            arrayList.add(makeCompletedRequest);
        }
        for (ObjectFieldOperation objectFieldOperation : this.operations.values()) {
            if ((objectFieldOperation instanceof CompoundOperation) && (encodeRestOp = ((CompoundOperation) objectFieldOperation).encodeRestOp(this)) != null && !encodeRestOp.isEmpty()) {
                arrayList.addAll(encodeRestOp);
            }
        }
        HashMap hashMap3 = new HashMap(1);
        hashMap3.put("requests", arrayList);
        return new JSONObject(hashMap3);
    }

    /* access modifiers changed from: protected */
    public List<AVObject> extractCascadingObjects(Object obj) {
        ArrayList arrayList = new ArrayList();
        if (obj instanceof AVObject) {
            AVObject aVObject = (AVObject) obj;
            if (StringUtil.isEmpty(aVObject.getObjectId())) {
                arrayList.add(aVObject);
                return arrayList;
            }
        }
        if (obj instanceof Collection) {
            for (Object obj2 : ((Collection) obj).toArray()) {
                List<AVObject> extractCascadingObjects = extractCascadingObjects(obj2);
                if (extractCascadingObjects != null && !extractCascadingObjects.isEmpty()) {
                    arrayList.addAll(extractCascadingObjects);
                }
            }
        }
        return arrayList;
    }

    /* access modifiers changed from: protected */
    public Observable<List<AVObject>> generateCascadingSaveObjects() {
        ArrayList arrayList = new ArrayList();
        for (ObjectFieldOperation objectFieldOperation : this.operations.values()) {
            List<AVObject> extractCascadingObjects = extractCascadingObjects(objectFieldOperation.getValue());
            if (extractCascadingObjects != null && !extractCascadingObjects.isEmpty()) {
                arrayList.addAll(extractCascadingObjects);
            }
        }
        return Observable.just(arrayList).subscribeOn(Schedulers.io());
    }

    /* access modifiers changed from: protected */
    public List<AVFile> extractUnsavedFiles(Object obj) {
        ArrayList arrayList = new ArrayList();
        if (obj instanceof AVFile) {
            AVFile aVFile = (AVFile) obj;
            if (StringUtil.isEmpty(aVFile.getObjectId())) {
                arrayList.add(aVFile);
                return arrayList;
            }
        }
        if (obj instanceof Collection) {
            for (Object obj2 : ((Collection) obj).toArray()) {
                List<AVFile> extractUnsavedFiles = extractUnsavedFiles(obj2);
                if (extractUnsavedFiles != null && !extractUnsavedFiles.isEmpty()) {
                    arrayList.addAll(extractUnsavedFiles);
                }
            }
        }
        return arrayList;
    }

    /* access modifiers changed from: protected */
    public List<AVFile> getUnsavedFiles() {
        ArrayList arrayList = new ArrayList();
        for (ObjectFieldOperation objectFieldOperation : this.operations.values()) {
            List<AVFile> extractUnsavedFiles = extractUnsavedFiles(objectFieldOperation.getValue());
            if (extractUnsavedFiles != null && !extractUnsavedFiles.isEmpty()) {
                arrayList.addAll(extractUnsavedFiles);
            }
        }
        return arrayList;
    }

    /* access modifiers changed from: protected */
    public void onSaveSuccess() {
        this.operations.clear();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Observable<? extends AVObject> saveSelfOperations(AVSaveOption aVSaveOption) {
        final boolean isFetchWhenSave = aVSaveOption != null ? aVSaveOption.fetchWhenSave : isFetchWhenSave();
        if (!(aVSaveOption == null || aVSaveOption.matchQuery == null)) {
            String className2 = getClassName();
            if (!StringUtil.isEmpty(className2) && !className2.equals(aVSaveOption.matchQuery.getClassName())) {
                return Observable.error(new AVException(0, "AVObject class inconsistant with AVQuery in AVSaveOption"));
            }
        }
        JSONObject generateChangedParam = generateChangedParam();
        AVLogger aVLogger = logger;
        aVLogger.d("saveObject param: " + generateChangedParam.toJSONString());
        final String objectId2 = getObjectId();
        if (needBatchMode()) {
            aVLogger.w("Caution: batch mode will ignore fetchWhenSave flag and matchQuery.");
            if (!StringUtil.isEmpty(objectId2)) {
                return PaasClient.getStorageClient().batchUpdate(generateChangedParam).map(new Function<JSONObject, AVObject>() {
                    /* class cn.leancloud.AVObject.AnonymousClass2 */

                    public AVObject apply(JSONObject jSONObject) throws Exception {
                        if (jSONObject != null) {
                            AVLogger aVLogger = AVObject.logger;
                            aVLogger.d("batchUpdate result: " + jSONObject.toJSONString());
                            Map map = (Map) jSONObject.getObject(objectId2, Map.class);
                            if (map != null) {
                                AVUtils.mergeConcurrentMap(AVObject.this.serverData, map);
                                AVObject.this.onSaveSuccess();
                            }
                        }
                        return AVObject.this;
                    }
                });
            }
            aVLogger.d("request payload: " + generateChangedParam.toJSONString());
            return PaasClient.getStorageClient().batchSave(generateChangedParam).map(new Function<JSONArray, AVObject>() {
                /* class cn.leancloud.AVObject.AnonymousClass1 */

                public AVObject apply(JSONArray jSONArray) throws Exception {
                    if (jSONArray != null && !jSONArray.isEmpty()) {
                        AVLogger aVLogger = AVObject.logger;
                        aVLogger.d("batchSave result: " + jSONArray.toJSONString());
                        Map map = (Map) jSONArray.getObject(jSONArray.size() + -1, Map.class);
                        if (map != null) {
                            AVUtils.mergeConcurrentMap(AVObject.this.serverData, map);
                            AVObject.this.onSaveSuccess();
                        }
                    }
                    return AVObject.this;
                }
            });
        }
        JSONObject jSONObject = null;
        if (!(aVSaveOption == null || aVSaveOption.matchQuery == null)) {
            jSONObject = new JSONObject(aVSaveOption.matchQuery.conditions.compileWhereOperationMap());
        }
        if (this.totallyOverwrite) {
            return PaasClient.getStorageClient().saveWholeObject(getClass(), this.endpointClassName, objectId2, generateChangedParam, isFetchWhenSave, jSONObject).map(new Function<AVObject, AVObject>() {
                /* class cn.leancloud.AVObject.AnonymousClass3 */

                public AVObject apply(AVObject aVObject) throws Exception {
                    AVObject.this.mergeRawData(aVObject, isFetchWhenSave);
                    AVObject.this.onSaveSuccess();
                    return AVObject.this;
                }
            });
        }
        if (StringUtil.isEmpty(objectId2)) {
            return PaasClient.getStorageClient().createObject(this.className, generateChangedParam, isFetchWhenSave, jSONObject).map(new Function<AVObject, AVObject>() {
                /* class cn.leancloud.AVObject.AnonymousClass4 */

                public AVObject apply(AVObject aVObject) throws Exception {
                    AVObject.this.mergeRawData(aVObject, isFetchWhenSave);
                    AVObject.this.onSaveSuccess();
                    return AVObject.this;
                }
            });
        }
        return PaasClient.getStorageClient().saveObject(this.className, getObjectId(), generateChangedParam, isFetchWhenSave, jSONObject).map(new Function<AVObject, AVObject>() {
            /* class cn.leancloud.AVObject.AnonymousClass5 */

            public AVObject apply(AVObject aVObject) throws Exception {
                AVObject.this.mergeRawData(aVObject, isFetchWhenSave);
                AVObject.this.onSaveSuccess();
                return AVObject.this;
            }
        });
    }

    public Observable<? extends AVObject> saveInBackground() {
        AVSaveOption aVSaveOption;
        if (this.totallyOverwrite) {
            aVSaveOption = new AVSaveOption();
            aVSaveOption.setFetchWhenSave(true);
        } else {
            aVSaveOption = null;
        }
        return saveInBackground(aVSaveOption);
    }

    public Observable<? extends AVObject> saveInBackground(final AVSaveOption aVSaveOption) {
        if (hasCircleReference(new HashMap())) {
            return Observable.error(new AVException((int) AVException.CIRCLE_REFERENCE, "Found a circular dependency when saving."));
        }
        return generateCascadingSaveObjects().flatMap(new Function<List<AVObject>, Observable<? extends AVObject>>() {
            /* class cn.leancloud.AVObject.AnonymousClass6 */

            public Observable<? extends AVObject> apply(List<AVObject> list) throws Exception {
                AVLogger aVLogger = AVObject.logger;
                aVLogger.d("First, try to execute save operations in thread: " + Thread.currentThread());
                for (AVObject aVObject : list) {
                    aVObject.save();
                }
                AVObject.logger.d("Second, save object itself...");
                return AVObject.this.saveSelfOperations(aVSaveOption);
            }
        });
    }

    public boolean hasCircleReference(Map<AVObject, Boolean> map) {
        if (map == null) {
            return false;
        }
        map.put(this, true);
        Iterator<ObjectFieldOperation> it = this.operations.values().iterator();
        while (true) {
            boolean z = false;
            while (true) {
                if (!it.hasNext()) {
                    return z;
                }
                ObjectFieldOperation next = it.next();
                if (z || next.checkCircleReference(map)) {
                    z = true;
                }
            }
        }
    }

    public void save() {
        saveInBackground().blockingSubscribe();
    }

    public static void saveAll(Collection<? extends AVObject> collection) throws AVException {
        saveAllInBackground(collection).blockingSubscribe();
    }

    private static Observable<List<AVFile>> extractSaveAheadFiles(Collection<? extends AVObject> collection) {
        ArrayList arrayList = new ArrayList();
        for (AVObject aVObject : collection) {
            List<AVFile> unsavedFiles = aVObject.getUnsavedFiles();
            if (unsavedFiles != null && !unsavedFiles.isEmpty()) {
                arrayList.addAll(unsavedFiles);
            }
        }
        return Observable.just(arrayList).subscribeOn(Schedulers.io());
    }

    public static Observable<JSONArray> saveAllInBackground(final Collection<? extends AVObject> collection) {
        if (collection == null || collection.isEmpty()) {
            return Observable.just(new JSONArray());
        }
        for (AVObject aVObject : collection) {
            if (aVObject.hasCircleReference(new HashMap())) {
                return Observable.error(new AVException((int) AVException.CIRCLE_REFERENCE, "Found a circular dependency when saving."));
            }
        }
        return extractSaveAheadFiles(collection).flatMap(new Function<List<AVFile>, ObservableSource<JSONArray>>() {
            /* class cn.leancloud.AVObject.AnonymousClass7 */

            public ObservableSource<JSONArray> apply(List<AVFile> list) throws Exception {
                AVObject.logger.d("begin to save objects with batch mode...");
                if (list != null && !list.isEmpty()) {
                    for (AVFile aVFile : list) {
                        aVFile.save();
                    }
                }
                JSONArray jSONArray = new JSONArray();
                for (AVObject aVObject : collection) {
                    JSONObject generateChangedParam = aVObject.generateChangedParam();
                    JSONObject jSONObject = new JSONObject();
                    jSONObject.put(BaseOperation.KEY_HTTP_METHOD, (Object) aVObject.getRequestMethod());
                    jSONObject.put(BaseOperation.KEY_PATH, (Object) aVObject.getRequestRawEndpoint());
                    jSONObject.put(BaseOperation.KEY_BODY, (Object) generateChangedParam);
                    jSONArray.add(jSONObject);
                }
                JSONObject jSONObject2 = new JSONObject();
                jSONObject2.put("requests", (Object) jSONArray);
                return PaasClient.getStorageClient().batchSave(jSONObject2).map(new Function<JSONArray, JSONArray>() {
                    /* class cn.leancloud.AVObject.AnonymousClass7.AnonymousClass1 */

                    public JSONArray apply(JSONArray jSONArray) throws Exception {
                        if (jSONArray != null && collection.size() == jSONArray.size()) {
                            AVLogger aVLogger = AVObject.logger;
                            aVLogger.d("batchSave result: " + jSONArray.toJSONString());
                            Iterator it = collection.iterator();
                            for (int i = 0; i < jSONArray.size() && it.hasNext(); i++) {
                                JSONObject jSONObject = jSONArray.getJSONObject(i);
                                AVObject aVObject = (AVObject) it.next();
                                if (jSONObject.containsKey("success")) {
                                    AVUtils.mergeConcurrentMap(aVObject.serverData, jSONObject.getJSONObject("success"));
                                    aVObject.onSaveSuccess();
                                } else if (jSONObject.containsKey(b.J)) {
                                    aVObject.onSaveFailure();
                                }
                            }
                        }
                        return jSONArray;
                    }
                });
            }
        });
    }

    public void saveEventually() throws AVException {
        if (!this.operations.isEmpty()) {
            if (!hasCircleReference(new HashMap())) {
                NetworkingDetector globalNetworkingDetector = AppConfiguration.getGlobalNetworkingDetector();
                if (globalNetworkingDetector == null || !globalNetworkingDetector.isConnected()) {
                    add2ArchivedRequest(false);
                } else {
                    saveInBackground().subscribe(new Observer<AVObject>() {
                        /* class cn.leancloud.AVObject.AnonymousClass8 */

                        @Override // io.reactivex.Observer
                        public void onComplete() {
                        }

                        @Override // io.reactivex.Observer
                        public void onSubscribe(Disposable disposable) {
                        }

                        public void onNext(AVObject aVObject) {
                            AVObject.logger.d("succeed to save directly");
                        }

                        @Override // io.reactivex.Observer
                        public void onError(Throwable th) {
                            AVObject.this.add2ArchivedRequest(false);
                        }
                    });
                }
            } else {
                throw new AVException((int) AVException.CIRCLE_REFERENCE, "Found a circular dependency when saving.");
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void add2ArchivedRequest(boolean z) {
        ArchivedRequests instance = ArchivedRequests.getInstance();
        if (z) {
            instance.deleteEventually(this);
        } else {
            instance.saveEventually(this);
        }
    }

    public void deleteEventually() {
        if (StringUtil.isEmpty(getObjectId())) {
            logger.w("objectId is empty, you couldn't delete a persistent object.");
            return;
        }
        NetworkingDetector globalNetworkingDetector = AppConfiguration.getGlobalNetworkingDetector();
        if (globalNetworkingDetector == null || !globalNetworkingDetector.isConnected()) {
            add2ArchivedRequest(true);
        } else {
            deleteInBackground().subscribe(new Observer<AVNull>() {
                /* class cn.leancloud.AVObject.AnonymousClass9 */

                @Override // io.reactivex.Observer
                public void onComplete() {
                }

                @Override // io.reactivex.Observer
                public void onSubscribe(Disposable disposable) {
                }

                public void onNext(AVNull aVNull) {
                    AVObject.logger.d("succeed to delete directly.");
                }

                @Override // io.reactivex.Observer
                public void onError(Throwable th) {
                    AVObject.this.add2ArchivedRequest(true);
                }
            });
        }
    }

    public Observable<AVNull> deleteInBackground() {
        HashMap hashMap = new HashMap();
        if (this.ignoreHooks.size() > 0) {
            hashMap.put(KEY_IGNORE_HOOKS, this.ignoreHooks);
        }
        if (this.totallyOverwrite) {
            return PaasClient.getStorageClient().deleteWholeObject(this.endpointClassName, getObjectId(), hashMap);
        }
        return PaasClient.getStorageClient().deleteObject(this.className, getObjectId(), hashMap);
    }

    public void delete() {
        deleteInBackground().blockingSubscribe();
    }

    public static void deleteAll(Collection<? extends AVObject> collection) throws AVException {
        deleteAllInBackground(collection).blockingSubscribe();
    }

    public static Observable<AVNull> deleteAllInBackground(Collection<? extends AVObject> collection) {
        if (collection == null || collection.isEmpty()) {
            return Observable.just(AVNull.getINSTANCE());
        }
        String str = null;
        HashMap hashMap = new HashMap();
        StringBuilder sb = new StringBuilder();
        for (AVObject aVObject : collection) {
            if (StringUtil.isEmpty(aVObject.getObjectId()) || StringUtil.isEmpty(aVObject.getClassName())) {
                return Observable.error(new IllegalArgumentException("Invalid AVObject, the class name or objectId is blank."));
            }
            if (str == null) {
                str = aVObject.getClassName();
                sb.append(aVObject.getObjectId());
            } else if (!str.equals(aVObject.getClassName())) {
                return Observable.error(new IllegalArgumentException("The objects class name must be the same."));
            } else {
                sb.append(",");
                sb.append(aVObject.getObjectId());
            }
        }
        return PaasClient.getStorageClient().deleteObject(str, sb.toString(), hashMap);
    }

    public void refresh() {
        refresh(null);
    }

    public void refresh(String str) {
        refreshInBackground(str).blockingSubscribe();
    }

    public Observable<AVObject> refreshInBackground() {
        return refreshInBackground(null);
    }

    public Observable<AVObject> refreshInBackground(final String str) {
        if (this.totallyOverwrite) {
            return PaasClient.getStorageClient().getWholeObject(this.endpointClassName, getObjectId(), str).map(new Function<AVObject, AVObject>() {
                /* class cn.leancloud.AVObject.AnonymousClass10 */

                public AVObject apply(AVObject aVObject) throws Exception {
                    AVObject.this.serverData.clear();
                    AVObject.this.serverData.putAll(aVObject.serverData);
                    AVObject.this.onDataSynchronized();
                    return AVObject.this;
                }
            });
        }
        return PaasClient.getStorageClient().fetchObject(this.className, getObjectId(), str).map(new Function<AVObject, AVObject>() {
            /* class cn.leancloud.AVObject.AnonymousClass11 */

            public AVObject apply(AVObject aVObject) throws Exception {
                if (StringUtil.isEmpty(str)) {
                    if (!AVObject.this.className.equals(AVUser.CLASS_NAME)) {
                        AVObject aVObject2 = AVObject.this;
                        if (!(aVObject2 instanceof AVUser)) {
                            aVObject2.serverData.clear();
                        }
                    }
                    Object obj = AVObject.this.serverData.get(AVUser.ATTR_SESSION_TOKEN);
                    AVObject.this.serverData.clear();
                    if (obj != null) {
                        AVObject.this.serverData.put(AVUser.ATTR_SESSION_TOKEN, obj);
                    }
                }
                AVObject.this.serverData.putAll(aVObject.serverData);
                AVObject.this.onDataSynchronized();
                return AVObject.this;
            }
        });
    }

    public AVObject fetch() {
        return fetch(null);
    }

    public AVObject fetch(String str) {
        refresh(str);
        return this;
    }

    public Observable<AVObject> fetchInBackground() {
        return refreshInBackground();
    }

    public Observable<AVObject> fetchInBackground(String str) {
        return refreshInBackground(str);
    }

    public Observable<AVObject> fetchIfNeededInBackground() {
        if (StringUtil.isEmpty(getObjectId()) || this.serverData.size() <= 1) {
            return refreshInBackground();
        }
        return Observable.just(this);
    }

    public Observable<AVObject> fetchIfNeededInBackground(String str) {
        if (StringUtil.isEmpty(getObjectId()) || this.serverData.size() <= 1) {
            return refreshInBackground(str);
        }
        return Observable.just(this);
    }

    public AVObject fetchIfNeeded() {
        fetchIfNeededInBackground().blockingSubscribe();
        return this;
    }

    /* access modifiers changed from: protected */
    public void resetAll() {
        this.objectId = "";
        this.acl = null;
        this.serverData.clear();
        this.operations.clear();
    }

    /* access modifiers changed from: protected */
    public void resetByRawData(AVObject aVObject) {
        resetAll();
        if (aVObject != null) {
            this.serverData.putAll(aVObject.serverData);
            this.operations.putAll(aVObject.operations);
        }
    }

    /* access modifiers changed from: package-private */
    public void mergeRawData(AVObject aVObject, boolean z) {
        if (aVObject != null) {
            this.serverData.putAll(aVObject.serverData);
        }
        if (!z && AppConfiguration.isAutoMergeOperationDataWhenSave()) {
            for (Map.Entry<String, ObjectFieldOperation> entry : this.operations.entrySet()) {
                String key = entry.getKey();
                Object obj = get(key);
                if (obj == null) {
                    this.serverData.remove(key);
                } else {
                    this.serverData.put(key, obj);
                }
            }
        }
    }

    public void resetServerData(Map<String, Object> map) {
        this.serverData.clear();
        AVUtils.mergeConcurrentMap(this.serverData, map);
        this.operations.clear();
    }

    @JSONField(serialize = false)
    public String getRequestRawEndpoint() {
        if (StringUtil.isEmpty(getObjectId())) {
            return "/1.1/classes/" + getClassName();
        }
        return "/1.1/classes/" + getClassName() + "/" + getObjectId();
    }

    @JSONField(serialize = false)
    public String getRequestMethod() {
        return StringUtil.isEmpty(getObjectId()) ? "POST" : "PUT";
    }

    public static <T extends AVObject> void registerSubclass(Class<T> cls) {
        Transformer.registerClass(cls);
    }

    public synchronized AVACL getACL() {
        if (this.acl == null) {
            this.acl = generateACLFromServerData();
        }
        return this.acl;
    }

    public synchronized void setACL(AVACL avacl) {
        this.acl = avacl;
    }

    /* access modifiers changed from: protected */
    public AVACL generateACLFromServerData() {
        if (!this.serverData.containsKey(KEY_ACL)) {
            return new AVACL();
        }
        Object obj = this.serverData.get(KEY_ACL);
        if (obj instanceof HashMap) {
            return new AVACL((HashMap) obj);
        }
        return new AVACL();
    }

    public static <T extends AVObject> AVQuery<T> getQuery(Class<T> cls) {
        return new AVQuery<>(Transformer.getSubClassName(cls), cls);
    }

    public JSONObject toJSONObject() {
        return new JSONObject(this.serverData);
    }

    public String toJSONString() {
        if (AVOSCloud.isEnableCircularReferenceDetect()) {
            return JSON.toJSONString(this, ObjectValueFilter.instance, SerializerFeature.WriteClassName);
        }
        return JSON.toJSONString(this, ObjectValueFilter.instance, SerializerFeature.WriteClassName, SerializerFeature.DisableCircularReferenceDetect);
    }

    public static AVObject parseAVObject(String str) {
        if (StringUtil.isEmpty(str)) {
            return null;
        }
        return (AVObject) JSON.parseObject(str.replaceAll("^\\{\\s*\"@type\":\\s*\"[A-Za-z\\.]+\",", "{").replaceAll("\"@type\":\\s*\"com.avos.avoscloud.AVObject\",", "\"@type\":\"cn.leancloud.AVObject\",").replaceAll("\"@type\":\\s*\"com.avos.avoscloud.AVInstallation\",", "\"@type\":\"cn.leancloud.AVInstallation\",").replaceAll("\"@type\":\\s*\"com.avos.avoscloud.AVUser\",", "\"@type\":\"cn.leancloud.AVUser\",").replaceAll("\"@type\":\\s*\"com.avos.avoscloud.AVStatus\",", "\"@type\":\"cn.leancloud.AVStatus\",").replaceAll("\"@type\":\\s*\"com.avos.avoscloud.AVRole\",", "\"@type\":\"cn.leancloud.AVRole\",").replaceAll("\"@type\":\\s*\"com.avos.avoscloud.AVFile\",", "\"@type\":\"cn.leancloud.AVFile\",").replaceAll("\"@type\":\\s*\"com.avos.avoscloud.ops.[A-Za-z]+Op\",", ""), AVObject.class, Feature.SupportAutoType);
    }

    public static AVObject createWithoutData(String str, String str2) {
        AVObject aVObject = new AVObject(str);
        aVObject.setObjectId(str2);
        return aVObject;
    }

    public static <T extends AVObject> T createWithoutData(Class<T> cls, String str) throws AVException {
        try {
            T newInstance = cls.newInstance();
            newInstance.setClassName(Transformer.getSubClassName(cls));
            newInstance.setObjectId(str);
            return newInstance;
        } catch (Exception e) {
            throw new AVException(e);
        }
    }

    public void disableBeforeHook() {
        Collections.addAll(this.ignoreHooks, Hook.beforeSave, Hook.beforeUpdate, Hook.beforeDelete);
    }

    public void disableAfterHook() {
        Collections.addAll(this.ignoreHooks, Hook.afterSave, Hook.afterUpdate, Hook.afterDelete);
    }

    public void ignoreHook(Hook hook) {
        this.ignoreHooks.add(hook);
    }

    /* JADX DEBUG: Multi-variable search result rejected for r2v0, resolved type: cn.leancloud.AVObject */
    /* JADX WARN: Multi-variable type inference failed */
    protected static <T extends AVObject> T cast(AVObject aVObject, Class<T> cls) throws Exception {
        if (cls.getClass().isAssignableFrom(aVObject.getClass())) {
            return aVObject;
        }
        T newInstance = cls.newInstance();
        newInstance.className = aVObject.className;
        newInstance.objectId = aVObject.objectId;
        newInstance.serverData.putAll(aVObject.serverData);
        newInstance.operations.putAll(aVObject.operations);
        newInstance.acl = aVObject.acl;
        newInstance.endpointClassName = aVObject.endpointClassName;
        return newInstance;
    }

    public String toString() {
        return toJSONString();
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (!(obj instanceof AVObject)) {
            return false;
        }
        AVObject aVObject = (AVObject) obj;
        if (isFetchWhenSave() != aVObject.isFetchWhenSave() || !Objects.equals(getClassName(), aVObject.getClassName()) || !Objects.equals(getServerData(), aVObject.getServerData()) || !Objects.equals(this.operations, aVObject.operations) || !Objects.equals(this.acl, aVObject.acl)) {
            return false;
        }
        return true;
    }

    public int hashCode() {
        return Objects.hash(getClassName(), getServerData(), this.operations, this.acl, Boolean.valueOf(isFetchWhenSave()));
    }
}
