package cn.leancloud.cache;

import cn.leancloud.AVLogger;
import cn.leancloud.AVObject;
import cn.leancloud.codec.MD5;
import cn.leancloud.core.AppConfiguration;
import cn.leancloud.query.AVQueryResult;
import cn.leancloud.utils.LogUtil;
import com.bumptech.glide.load.Key;
import io.reactivex.Observable;
import io.reactivex.schedulers.Schedulers;
import java.io.File;
import java.io.FileNotFoundException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.FutureTask;

public class QueryResultCache extends LocalStorage {
    private static QueryResultCache INSTANCE = null;
    private static final AVLogger LOGGER = LogUtil.getLogger(QueryResultCache.class);
    private ExecutorService executor = Executors.newFixedThreadPool(2);

    public static synchronized QueryResultCache getInstance() {
        QueryResultCache queryResultCache;
        synchronized (QueryResultCache.class) {
            if (INSTANCE == null) {
                INSTANCE = new QueryResultCache();
            }
            queryResultCache = INSTANCE;
        }
        return queryResultCache;
    }

    private QueryResultCache() {
        super(AppConfiguration.getQueryResultCacheDir());
    }

    public String cacheResult(String str, String str2) {
        AVLogger aVLogger = LOGGER;
        aVLogger.d("save cache. key=" + str + ", value=" + str2);
        try {
            return super.saveData(str, str2.getBytes(Key.STRING_CHARSET_NAME));
        } catch (Exception e) {
            LOGGER.w(e);
            return null;
        }
    }

    public static String generateKeyForQueryCondition(String str, Map<String, String> map) {
        StringBuilder sb = new StringBuilder();
        sb.append(str);
        sb.append(":");
        for (Map.Entry<String, String> entry : map.entrySet()) {
            sb.append(entry.getKey());
            sb.append("=");
            sb.append(entry.getValue());
            sb.append("&");
        }
        return MD5.computeMD5(sb.toString());
    }

    public static String generateCachedKey(String str, Map<String, Object> map) {
        StringBuilder sb = new StringBuilder();
        sb.append(str);
        sb.append(":");
        for (Map.Entry<String, Object> entry : map.entrySet()) {
            sb.append(entry.getKey());
            sb.append("=");
            sb.append(entry.getValue().toString());
            sb.append("&");
        }
        return MD5.computeMD5(sb.toString());
    }

    public boolean hasCachedResult(String str, Map<String, String> map, long j) {
        String generateKeyForQueryCondition = generateKeyForQueryCondition(str, map);
        File cacheFile = getCacheFile(generateKeyForQueryCondition);
        if (cacheFile == null || !cacheFile.exists()) {
            AVLogger aVLogger = LOGGER;
            aVLogger.d("cache file(key=" + generateKeyForQueryCondition + ") not existed.");
            return false;
        } else if (j <= 0 || System.currentTimeMillis() - cacheFile.lastModified() <= j) {
            return true;
        } else {
            AVLogger aVLogger2 = LOGGER;
            aVLogger2.d("cache file(key=" + generateKeyForQueryCondition + ") is expired.");
            return false;
        }
    }

    public Observable<String> getCacheRawResult(String str, Map<String, String> map, long j, boolean z) {
        AVLogger aVLogger = LOGGER;
        aVLogger.d("try to get cache raw result for class:" + str);
        return getCacheRawResult(str, generateKeyForQueryCondition(str, map), j, z);
    }

    public Observable<String> getCacheRawResult(String str, final String str2, final long j, final boolean z) {
        AVLogger aVLogger = LOGGER;
        aVLogger.d("try to get cache raw result for class:" + str);
        AppConfiguration.SchedulerCreator defaultScheduler = AppConfiguration.getDefaultScheduler();
        boolean isAsynchronized = AppConfiguration.isAsynchronized();
        FutureTask futureTask = new FutureTask(new Callable<String>() {
            /* class cn.leancloud.cache.QueryResultCache.AnonymousClass1 */

            @Override // java.util.concurrent.Callable
            public String call() throws Exception {
                File cacheFile = QueryResultCache.this.getCacheFile(str2);
                if (cacheFile == null || !cacheFile.exists()) {
                    AVLogger aVLogger = QueryResultCache.LOGGER;
                    aVLogger.d("cache file(key=" + str2 + ") not existed.");
                    if (!z) {
                        return "";
                    }
                    throw new FileNotFoundException("cache is not existed.");
                } else if (j <= 0 || System.currentTimeMillis() - cacheFile.lastModified() <= j) {
                    byte[] readData = QueryResultCache.this.readData(cacheFile);
                    if (readData == null) {
                        AVLogger aVLogger2 = QueryResultCache.LOGGER;
                        aVLogger2.d("cache file(key=" + str2 + ") is empty.");
                        if (!z) {
                            return "";
                        }
                        throw new InterruptedException("failed to read cache file.");
                    }
                    String str = new String(readData, 0, readData.length, Key.STRING_CHARSET_NAME);
                    AVLogger aVLogger3 = QueryResultCache.LOGGER;
                    aVLogger3.d("cache file(key=" + str2 + "), content: " + str);
                    return str;
                } else {
                    AVLogger aVLogger4 = QueryResultCache.LOGGER;
                    aVLogger4.d("cache file(key=" + str2 + ") is expired.");
                    if (!z) {
                        return "";
                    }
                    throw new FileNotFoundException("cache file is expired.");
                }
            }
        });
        this.executor.submit(futureTask);
        Observable<String> fromFuture = Observable.fromFuture(futureTask);
        if (isAsynchronized) {
            fromFuture = fromFuture.subscribeOn(Schedulers.io());
        }
        return defaultScheduler != null ? fromFuture.observeOn(defaultScheduler.create()) : fromFuture;
    }

    public Observable<List<AVObject>> getCacheResult(final String str, final Map<String, String> map, final long j, final boolean z) {
        AVLogger aVLogger = LOGGER;
        aVLogger.d("try to get cache result for class:" + str);
        FutureTask futureTask = new FutureTask(new Callable<List<AVObject>>() {
            /* class cn.leancloud.cache.QueryResultCache.AnonymousClass2 */

            @Override // java.util.concurrent.Callable
            public List<AVObject> call() throws Exception {
                String generateKeyForQueryCondition = QueryResultCache.generateKeyForQueryCondition(str, map);
                File cacheFile = QueryResultCache.this.getCacheFile(generateKeyForQueryCondition);
                if (cacheFile == null || !cacheFile.exists()) {
                    AVLogger aVLogger = QueryResultCache.LOGGER;
                    aVLogger.d("cache file(key=" + generateKeyForQueryCondition + ") not existed.");
                    if (z) {
                        return new ArrayList();
                    }
                    throw new FileNotFoundException("cache is not existed.");
                } else if (j <= 0 || System.currentTimeMillis() - cacheFile.lastModified() <= j) {
                    byte[] readData = QueryResultCache.this.readData(cacheFile);
                    if (readData == null) {
                        AVLogger aVLogger2 = QueryResultCache.LOGGER;
                        aVLogger2.d("cache file(key=" + generateKeyForQueryCondition + ") is empty.");
                        if (z) {
                            return new ArrayList();
                        }
                        throw new InterruptedException("failed to read cache file.");
                    }
                    String str = new String(readData, 0, readData.length, Key.STRING_CHARSET_NAME);
                    AVLogger aVLogger3 = QueryResultCache.LOGGER;
                    aVLogger3.d("cache file(key=" + generateKeyForQueryCondition + "), content: " + str);
                    return AVQueryResult.fromJSONString(str).getResults();
                } else {
                    AVLogger aVLogger4 = QueryResultCache.LOGGER;
                    aVLogger4.d("cache file(key=" + generateKeyForQueryCondition + ") is expired.");
                    if (z) {
                        return new ArrayList();
                    }
                    throw new FileNotFoundException("cache file is expired.");
                }
            }
        });
        this.executor.submit(futureTask);
        return Observable.fromFuture(futureTask);
    }
}
