package cn.leancloud.core;

import cn.leancloud.AVFile;
import cn.leancloud.AVLogger;
import cn.leancloud.AVObject;
import cn.leancloud.AVQuery;
import cn.leancloud.AVStatus;
import cn.leancloud.AVUser;
import cn.leancloud.Transformer;
import cn.leancloud.cache.QueryResultCache;
import cn.leancloud.core.AppConfiguration;
import cn.leancloud.ops.Utils;
import cn.leancloud.query.AVQueryResult;
import cn.leancloud.search.AVSearchResponse;
import cn.leancloud.service.APIService;
import cn.leancloud.sms.AVCaptchaDigest;
import cn.leancloud.sms.AVCaptchaOption;
import cn.leancloud.sms.AVCaptchaValidateResult;
import cn.leancloud.types.AVDate;
import cn.leancloud.types.AVNull;
import cn.leancloud.upload.FileUploadToken;
import cn.leancloud.utils.ErrorUtils;
import cn.leancloud.utils.LogUtil;
import cn.leancloud.utils.StringUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import io.reactivex.Observable;
import io.reactivex.ObservableSource;
import io.reactivex.Scheduler;
import io.reactivex.functions.Function;
import io.reactivex.schedulers.Schedulers;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class StorageClient {
    private static AVLogger LOGGER = LogUtil.getLogger(StorageClient.class);
    private APIService apiService = null;
    private boolean asynchronized = false;
    private AVUser currentUser = null;
    private AppConfiguration.SchedulerCreator defaultCreator = null;
    private QueryResultCache queryResultCache = QueryResultCache.getInstance();

    /* access modifiers changed from: package-private */
    public interface QueryExecutor {
        <T> Observable<T> executor();
    }

    public StorageClient(APIService aPIService, boolean z, AppConfiguration.SchedulerCreator schedulerCreator) {
        this.apiService = aPIService;
        this.asynchronized = z;
        this.defaultCreator = schedulerCreator;
    }

    public void setCurrentUser(AVUser aVUser) {
        this.currentUser = aVUser;
    }

    public AVUser getCurrentUser() {
        return this.currentUser;
    }

    public Observable wrapObservable(Observable observable) {
        if (observable == null) {
            return null;
        }
        if (this.asynchronized) {
            observable = observable.subscribeOn(Schedulers.io());
        }
        AppConfiguration.SchedulerCreator schedulerCreator = this.defaultCreator;
        if (schedulerCreator != null) {
            observable = observable.observeOn(schedulerCreator.create());
        }
        return observable.onErrorResumeNext(new Function<Throwable, ObservableSource>() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass1 */

            public ObservableSource apply(Throwable th) throws Exception {
                return Observable.error(ErrorUtils.propagateException(th));
            }
        });
    }

    private Observable wrapObservableInBackground(Observable observable) {
        if (observable == null) {
            return null;
        }
        Scheduler io2 = Schedulers.io();
        if (this.asynchronized) {
            observable = observable.subscribeOn(io2);
        }
        return this.defaultCreator != null ? observable.observeOn(io2) : observable;
    }

    public Observable<AVDate> getServerTime() {
        return wrapObservable(this.apiService.currentTimeMillis());
    }

    public Observable<? extends AVObject> fetchObject(final String str, String str2, String str3) {
        Observable<? extends AVObject> observable;
        if (StringUtil.isEmpty(str3)) {
            observable = wrapObservable(this.apiService.fetchObject(str, str2));
        } else {
            observable = wrapObservable(this.apiService.fetchObject(str, str2, str3));
        }
        if (observable == null) {
            return observable;
        }
        return observable.map(new Function<AVObject, AVObject>() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass2 */

            public AVObject apply(AVObject aVObject) throws Exception {
                return Transformer.transform(aVObject, str);
            }
        });
    }

    public boolean hasCachedResult(String str, Map<String, String> map, long j) {
        return QueryResultCache.getInstance().hasCachedResult(str, map, j);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Observable<AVQueryResult> queryRemoteServer(String str, Map<String, String> map) {
        if (AVUser.CLASS_NAME.equalsIgnoreCase(str)) {
            return wrapObservable(this.apiService.queryUsers(map));
        }
        return wrapObservable(this.apiService.queryObjects(str, map));
    }

    public Observable<List<AVObject>> queryObjects(final String str, final Map<String, String> map, AVQuery.CachePolicy cachePolicy, final long j) {
        final String generateKeyForQueryCondition = QueryResultCache.generateKeyForQueryCondition(str, map);
        int i = AnonymousClass28.$SwitchMap$cn$leancloud$AVQuery$CachePolicy[cachePolicy.ordinal()];
        if (i == 1) {
            return wrapObservable(QueryResultCache.getInstance().getCacheResult(str, map, j, true));
        }
        if (i == 2) {
            return wrapObservable(QueryResultCache.getInstance().getCacheResult(str, map, j, false)).onErrorResumeNext(new Function<Throwable, ObservableSource<? extends List<AVObject>>>() {
                /* class cn.leancloud.core.StorageClient.AnonymousClass3 */

                public ObservableSource<? extends List<AVObject>> apply(Throwable th) throws Exception {
                    AVLogger aVLogger = StorageClient.LOGGER;
                    aVLogger.d("failed to query local cache, cause: " + th.getMessage() + ", try to query networking");
                    return StorageClient.this.queryRemoteServer(str, map).map(new Function<AVQueryResult, List<AVObject>>() {
                        /* class cn.leancloud.core.StorageClient.AnonymousClass3.AnonymousClass1 */

                        public List<AVObject> apply(AVQueryResult aVQueryResult) throws Exception {
                            aVQueryResult.setClassName(str);
                            for (AVObject aVObject : aVQueryResult.getResults()) {
                                aVObject.setClassName(str);
                            }
                            QueryResultCache.getInstance().cacheResult(generateKeyForQueryCondition, aVQueryResult.toJSONString());
                            AVLogger aVLogger = StorageClient.LOGGER;
                            StringBuilder sb = new StringBuilder();
                            sb.append("invoke within StorageClient.queryObjects(). resultSize:");
                            sb.append(aVQueryResult.getResults() != null ? aVQueryResult.getResults().size() : 0);
                            aVLogger.d(sb.toString());
                            return aVQueryResult.getResults();
                        }
                    });
                }
            });
        }
        if (i != 3) {
            Observable<AVQueryResult> queryRemoteServer = queryRemoteServer(str, map);
            if (queryRemoteServer != null) {
                return queryRemoteServer.map(new Function<AVQueryResult, List<AVObject>>() {
                    /* class cn.leancloud.core.StorageClient.AnonymousClass6 */

                    public List<AVObject> apply(AVQueryResult aVQueryResult) throws Exception {
                        aVQueryResult.setClassName(str);
                        for (AVObject aVObject : aVQueryResult.getResults()) {
                            aVObject.setClassName(str);
                        }
                        QueryResultCache.getInstance().cacheResult(generateKeyForQueryCondition, aVQueryResult.toJSONString());
                        AVLogger aVLogger = StorageClient.LOGGER;
                        StringBuilder sb = new StringBuilder();
                        sb.append("invoke within StorageClient.queryObjects(). resultSize:");
                        sb.append(aVQueryResult.getResults() != null ? aVQueryResult.getResults().size() : 0);
                        aVLogger.d(sb.toString());
                        return aVQueryResult.getResults();
                    }
                });
            }
        } else {
            Observable<AVQueryResult> queryRemoteServer2 = queryRemoteServer(str, map);
            if (queryRemoteServer2 != null) {
                return queryRemoteServer2.map(new Function<AVQueryResult, List<AVObject>>() {
                    /* class cn.leancloud.core.StorageClient.AnonymousClass5 */

                    public List<AVObject> apply(AVQueryResult aVQueryResult) throws Exception {
                        aVQueryResult.setClassName(str);
                        for (AVObject aVObject : aVQueryResult.getResults()) {
                            aVObject.setClassName(str);
                        }
                        QueryResultCache.getInstance().cacheResult(generateKeyForQueryCondition, aVQueryResult.toJSONString());
                        AVLogger aVLogger = StorageClient.LOGGER;
                        StringBuilder sb = new StringBuilder();
                        sb.append("invoke within StorageClient.queryObjects(). resultSize:");
                        sb.append(aVQueryResult.getResults() != null ? aVQueryResult.getResults().size() : 0);
                        aVLogger.d(sb.toString());
                        return aVQueryResult.getResults();
                    }
                }).onErrorResumeNext(new Function<Throwable, ObservableSource<? extends List<AVObject>>>() {
                    /* class cn.leancloud.core.StorageClient.AnonymousClass4 */

                    public ObservableSource<? extends List<AVObject>> apply(Throwable th) throws Exception {
                        AVLogger aVLogger = StorageClient.LOGGER;
                        aVLogger.d("failed to query networking, cause: " + th.getMessage() + ", try to query local cache.");
                        return QueryResultCache.getInstance().getCacheResult(str, map, j, true);
                    }
                });
            }
        }
        return null;
    }

    /* access modifiers changed from: package-private */
    /* renamed from: cn.leancloud.core.StorageClient$28  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass28 {
        static final /* synthetic */ int[] $SwitchMap$cn$leancloud$AVQuery$CachePolicy;

        /* JADX WARNING: Can't wrap try/catch for region: R(8:0|1|2|3|4|5|6|(3:7|8|10)) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0012 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x001d */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0028 */
        static {
            int[] iArr = new int[AVQuery.CachePolicy.values().length];
            $SwitchMap$cn$leancloud$AVQuery$CachePolicy = iArr;
            iArr[AVQuery.CachePolicy.CACHE_ONLY.ordinal()] = 1;
            $SwitchMap$cn$leancloud$AVQuery$CachePolicy[AVQuery.CachePolicy.CACHE_ELSE_NETWORK.ordinal()] = 2;
            $SwitchMap$cn$leancloud$AVQuery$CachePolicy[AVQuery.CachePolicy.NETWORK_ELSE_CACHE.ordinal()] = 3;
            try {
                $SwitchMap$cn$leancloud$AVQuery$CachePolicy[AVQuery.CachePolicy.IGNORE_CACHE.ordinal()] = 4;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    public Observable<AVQueryResult> cloudQuery(Map<String, String> map) {
        return wrapObservable(this.apiService.cloudQuery(map));
    }

    public Observable<Integer> queryCount(String str, Map<String, String> map) {
        Observable<AVQueryResult> queryRemoteServer = queryRemoteServer(str, map);
        if (queryRemoteServer == null) {
            return null;
        }
        return queryRemoteServer.map(new Function<AVQueryResult, Integer>() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass7 */

            public Integer apply(AVQueryResult aVQueryResult) throws Exception {
                AVLogger aVLogger = StorageClient.LOGGER;
                aVLogger.d("invoke within StorageClient.queryCount(). result:" + aVQueryResult + ", return:" + aVQueryResult.getCount());
                return Integer.valueOf(aVQueryResult.getCount());
            }
        });
    }

    public Observable<AVNull> deleteObject(String str, String str2, Map<String, Object> map) {
        return wrapObservable(this.apiService.deleteObject(str, str2, map));
    }

    public Observable<? extends AVObject> createObject(final String str, JSONObject jSONObject, boolean z, JSONObject jSONObject2) {
        Observable wrapObservable = wrapObservable(this.apiService.createObject(str, jSONObject, z, jSONObject2));
        if (wrapObservable == null) {
            return null;
        }
        return wrapObservable.map(new Function<AVObject, AVObject>() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass8 */

            public AVObject apply(AVObject aVObject) {
                StorageClient.LOGGER.d(aVObject.toString());
                return Transformer.transform(aVObject, str);
            }
        });
    }

    public Observable<? extends AVObject> saveObject(final String str, String str2, JSONObject jSONObject, boolean z, JSONObject jSONObject2) {
        Observable wrapObservable = wrapObservable(this.apiService.updateObject(str, str2, jSONObject, z, jSONObject2));
        if (wrapObservable == null) {
            return null;
        }
        return wrapObservable.map(new Function<AVObject, AVObject>() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass9 */

            public AVObject apply(AVObject aVObject) {
                AVLogger aVLogger = StorageClient.LOGGER;
                aVLogger.d("saveObject finished. intermediaObj=" + aVObject.toString() + ", convert to " + str);
                return Transformer.transform(aVObject, str);
            }
        });
    }

    public <E extends AVObject> Observable<E> saveWholeObject(final Class<E> cls, String str, String str2, JSONObject jSONObject, boolean z, JSONObject jSONObject2) {
        Observable observable;
        if (StringUtil.isEmpty(str2)) {
            observable = wrapObservable(this.apiService.saveWholeObject(str, jSONObject, z, jSONObject2));
        } else {
            observable = wrapObservable(this.apiService.saveWholeObject(str, str2, jSONObject, z, jSONObject2));
        }
        if (observable == null) {
            return null;
        }
        return observable.map(new Function<AVObject, E>() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass10 */

            public E apply(AVObject aVObject) throws Exception {
                return (E) Transformer.transform(aVObject, cls);
            }
        });
    }

    public Observable<AVObject> getWholeObject(String str, String str2, String str3) {
        return wrapObservable(this.apiService.getWholeObject(str, str2, str3));
    }

    public Observable<AVNull> deleteWholeObject(String str, String str2, Map<String, Object> map) {
        return wrapObservable(this.apiService.deleteWholeObject(str, str2, map));
    }

    public Observable<AVFile> fetchFile(String str) {
        Observable wrapObservable = wrapObservable(this.apiService.fetchFile(str));
        if (wrapObservable == null) {
            return null;
        }
        return wrapObservable.map(new Function<AVFile, AVFile>() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass11 */

            public AVFile apply(AVFile aVFile) throws Exception {
                aVFile.setClassName(AVFile.CLASS_NAME);
                return aVFile;
            }
        });
    }

    public Observable<FileUploadToken> newUploadToken(JSONObject jSONObject) {
        return wrapObservableInBackground(this.apiService.createUploadToken(jSONObject));
    }

    public void fileCallback(JSONObject jSONObject) throws IOException {
        this.apiService.fileCallback(jSONObject).execute();
    }

    public Observable<JSONArray> batchSave(JSONObject jSONObject) {
        return wrapObservable(this.apiService.batchCreate(jSONObject));
    }

    public Observable<JSONObject> batchUpdate(JSONObject jSONObject) {
        return wrapObservable(this.apiService.batchUpdate(jSONObject));
    }

    public Observable<AVUser> signUp(JSONObject jSONObject) {
        return wrapObservable(this.apiService.signup(jSONObject));
    }

    public Observable<AVUser> signUpWithFlag(JSONObject jSONObject, boolean z) {
        return wrapObservable(this.apiService.signup(jSONObject, z));
    }

    public <T extends AVUser> Observable<T> signUpOrLoginByMobilephone(final JSONObject jSONObject, final Class<T> cls) {
        return wrapObservable(this.apiService.signupByMobilePhone(jSONObject)).map(new Function<AVUser, T>() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass12 */

            public T apply(AVUser aVUser) throws Exception {
                T t = (T) ((AVUser) Transformer.transform(aVUser, cls));
                StorageClient.this.attachLoginInfo(jSONObject, t);
                AVUser.changeCurrentUser(t, true);
                return t;
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private <T extends AVUser> void attachLoginInfo(JSONObject jSONObject, T t) {
        if (jSONObject != null && t != null) {
            if (jSONObject.containsKey("email")) {
                t.setEmail(jSONObject.getString("email"));
            }
            if (jSONObject.containsKey(AVUser.ATTR_USERNAME)) {
                t.setUsername(jSONObject.getString(AVUser.ATTR_USERNAME));
            }
            if (jSONObject.containsKey(AVUser.ATTR_MOBILEPHONE)) {
                t.setMobilePhoneNumber(jSONObject.getString(AVUser.ATTR_MOBILEPHONE));
            }
        }
    }

    public <T extends AVUser> Observable<T> logIn(final JSONObject jSONObject, final Class<T> cls) {
        Observable wrapObservable = wrapObservable(this.apiService.login(jSONObject));
        if (wrapObservable == null) {
            return null;
        }
        return wrapObservable.map(new Function<AVUser, T>() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass13 */

            public T apply(AVUser aVUser) throws Exception {
                T t = (T) ((AVUser) Transformer.transform(aVUser, cls));
                StorageClient.this.attachLoginInfo(jSONObject, t);
                AVUser.changeCurrentUser(t, true);
                return t;
            }
        });
    }

    public Observable<Boolean> checkAuthenticated(String str) {
        HashMap hashMap = new HashMap(1);
        hashMap.put("session_token", str);
        Observable wrapObservable = wrapObservable(this.apiService.checkAuthenticated(hashMap));
        if (wrapObservable == null) {
            return Observable.just(false);
        }
        return wrapObservable.map(new Function<AVUser, Boolean>() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass14 */

            public Boolean apply(AVUser aVUser) throws Exception {
                if (aVUser != null) {
                    return true;
                }
                return false;
            }
        });
    }

    /* JADX DEBUG: Type inference failed for r3v3. Raw type applied. Possible types: io.reactivex.Observable<R>, io.reactivex.Observable<T extends cn.leancloud.AVUser> */
    public <T extends AVUser> Observable<T> createUserBySession(String str, final Class<T> cls) {
        HashMap hashMap = new HashMap(1);
        hashMap.put("session_token", str);
        return (Observable<R>) this.apiService.checkAuthenticated(hashMap).map(new Function<AVUser, T>() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass15 */

            public T apply(AVUser aVUser) throws Exception {
                if (aVUser != null) {
                    return (T) ((AVUser) Transformer.transform(aVUser, cls));
                }
                StorageClient.LOGGER.e("The mapper function returned a null value.");
                return null;
            }
        });
    }

    public Observable<Boolean> refreshSessionToken(final AVUser aVUser) {
        return wrapObservable(this.apiService.refreshSessionToken(aVUser.getObjectId()).map(new Function<AVUser, Boolean>() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass16 */

            public Boolean apply(AVUser aVUser) throws Exception {
                if (aVUser == null || StringUtil.isEmpty(aVUser.getSessionToken())) {
                    return false;
                }
                aVUser.internalChangeSessionToken(aVUser.getSessionToken());
                return true;
            }
        }));
    }

    public Observable<AVNull> requestResetPassword(String str) {
        HashMap hashMap = new HashMap();
        hashMap.put("email", str);
        return wrapObservable(this.apiService.requestResetPassword(hashMap));
    }

    public Observable<AVNull> requestResetPasswordBySmsCode(String str, String str2) {
        HashMap hashMap = new HashMap();
        hashMap.put(AVUser.ATTR_MOBILEPHONE, str);
        if (!StringUtil.isEmpty(str2)) {
            hashMap.put("validate_token", str2);
        }
        return wrapObservable(this.apiService.requestResetPasswordBySmsCode(hashMap));
    }

    public Observable<AVNull> requestEmailVerify(String str) {
        HashMap hashMap = new HashMap();
        hashMap.put("email", str);
        return wrapObservable(this.apiService.requestEmailVerify(hashMap));
    }

    public Observable<AVNull> requestMobilePhoneVerify(String str, String str2) {
        HashMap hashMap = new HashMap();
        hashMap.put(AVUser.ATTR_MOBILEPHONE, str);
        if (!StringUtil.isEmpty(str2)) {
            hashMap.put("validate_token", str2);
        }
        return wrapObservable(this.apiService.requestMobilePhoneVerify(hashMap));
    }

    public Observable<AVNull> verifyMobilePhone(String str) {
        return wrapObservable(this.apiService.verifyMobilePhone(str));
    }

    public Observable<AVNull> requestLoginSmsCode(String str, String str2) {
        HashMap hashMap = new HashMap();
        hashMap.put(AVUser.ATTR_MOBILEPHONE, str);
        if (!StringUtil.isEmpty(str2)) {
            hashMap.put("validate_token", str2);
        }
        return wrapObservable(this.apiService.requestLoginSmsCode(hashMap));
    }

    public Observable<AVNull> resetPasswordBySmsCode(String str, String str2) {
        HashMap hashMap = new HashMap();
        hashMap.put("password", str2);
        return wrapObservable(this.apiService.resetPasswordBySmsCode(str, hashMap));
    }

    public Observable<AVNull> updatePassword(final AVUser aVUser, String str, String str2) {
        if (aVUser == null) {
            return Observable.error(new IllegalArgumentException("user is null"));
        }
        if (StringUtil.isEmpty(str) || StringUtil.isEmpty(str2)) {
            return Observable.error(new IllegalArgumentException("old password or new password is empty"));
        }
        JSONObject jSONObject = new JSONObject();
        jSONObject.put("old_password", (Object) str);
        jSONObject.put("new_password", (Object) str2);
        return wrapObservable(this.apiService.updatePassword(aVUser.getObjectId(), jSONObject).map(new Function<AVUser, AVNull>() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass17 */

            public AVNull apply(AVUser aVUser) throws Exception {
                if (aVUser != null) {
                    aVUser.internalChangeSessionToken(aVUser.getSessionToken());
                }
                return new AVNull();
            }
        }));
    }

    public Observable<JSONObject> followUser(String str, String str2, Map<String, Object> map) {
        return wrapObservable(this.apiService.followUser(str, str2, map));
    }

    public Observable<JSONObject> unfollowUser(String str, String str2) {
        return wrapObservable(this.apiService.unfollowUser(str, str2));
    }

    public Observable<JSONObject> getFollowersAndFollowees(String str) {
        return wrapObservable(this.apiService.getFollowersAndFollowees(str));
    }

    public Observable<AVStatus> postStatus(Map<String, Object> map) {
        return wrapObservable(this.apiService.postStatus(map));
    }

    public Observable<AVStatus> fetchStatus(String str) {
        return wrapObservable(this.apiService.fetchSingleStatus(str));
    }

    public Observable<List<AVStatus>> queryStatus(Map<String, String> map) {
        return wrapObservable(this.apiService.fetchStatuses(map).map(new Function<AVQueryResult, List<AVStatus>>() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass18 */

            public List<AVStatus> apply(AVQueryResult aVQueryResult) throws Exception {
                if (aVQueryResult == null) {
                    StorageClient.LOGGER.e("The mapper function returned a null value.");
                    return null;
                }
                ArrayList arrayList = new ArrayList();
                for (AVObject aVObject : aVQueryResult.getResults()) {
                    arrayList.add(new AVStatus(aVObject));
                }
                return arrayList;
            }
        }));
    }

    public Observable<List<AVStatus>> queryInbox(Map<String, String> map) {
        return wrapObservable(this.apiService.queryInbox(map).map(new Function<AVQueryResult, List<AVStatus>>() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass19 */

            public List<AVStatus> apply(AVQueryResult aVQueryResult) throws Exception {
                if (aVQueryResult == null) {
                    StorageClient.LOGGER.e("The mapper function returned a null value.");
                    return null;
                }
                ArrayList arrayList = new ArrayList();
                for (AVObject aVObject : aVQueryResult.getResults()) {
                    arrayList.add(new AVStatus(aVObject));
                }
                return arrayList;
            }
        }));
    }

    public Observable<JSONObject> getInboxCount(Map<String, String> map) {
        return wrapObservable(this.apiService.getInboxCount(map));
    }

    public Observable<AVNull> deleteStatus(String str) {
        return wrapObservable(this.apiService.deleteStatus(str));
    }

    public Observable<AVNull> deleteInboxStatus(Map<String, Object> map) {
        return wrapObservable(this.apiService.deleteInboxStatus(map));
    }

    public <T> Observable<T> callRPC(String str, Object obj) {
        return callRPC(str, obj, false, null);
    }

    /* access modifiers changed from: package-private */
    public <T> Observable<T> callRPC(String str, Object obj, final boolean z, final String str2) {
        Observable wrapObservable = wrapObservable(this.apiService.cloudRPC(str, obj));
        if (wrapObservable == null) {
            return null;
        }
        return wrapObservable.map(new Function<Map<String, ?>, T>() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass20 */

            public T apply(Map<String, ?> map) throws Exception {
                try {
                    T t = (T) map.get("result");
                    if (z && !StringUtil.isEmpty(str2)) {
                        AVLogger aVLogger = StorageClient.LOGGER;
                        aVLogger.d("cache rpc result:" + JSON.toJSONString(t));
                        QueryResultCache.getInstance().cacheResult(str2, JSON.toJSONString(t));
                    }
                    return t instanceof Collection ? (T) Utils.getObjectFrom((Collection) t) : t instanceof Map ? (T) Utils.getObjectFrom((Map<String, Object>) t) : t;
                } catch (Exception e) {
                    AVLogger aVLogger2 = StorageClient.LOGGER;
                    aVLogger2.d("RPCFunction error: " + e.getMessage());
                    return null;
                }
            }
        });
    }

    public <T> Observable<T> callFunction(String str, Map<String, Object> map) {
        return callFunction(str, map, false, null);
    }

    /* access modifiers changed from: package-private */
    public <T> Observable<T> callFunction(String str, Map<String, Object> map, final boolean z, final String str2) {
        Observable wrapObservable = wrapObservable(this.apiService.cloudFunction(str, map));
        if (wrapObservable == null) {
            return null;
        }
        return wrapObservable.map(new Function<Map<String, ?>, T>() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass21 */

            public T apply(Map<String, ?> map) throws Exception {
                try {
                    T t = (T) map.get("result");
                    if (z && !StringUtil.isEmpty(str2)) {
                        AVLogger aVLogger = StorageClient.LOGGER;
                        aVLogger.d("cache cloud function result:" + JSON.toJSONString(t));
                        QueryResultCache.getInstance().cacheResult(str2, JSON.toJSONString(t));
                    }
                    return t instanceof Collection ? (T) Utils.getObjectFrom((Collection) t) : t instanceof Map ? (T) Utils.getObjectFrom((Map<String, Object>) t) : t;
                } catch (Exception e) {
                    AVLogger aVLogger2 = StorageClient.LOGGER;
                    aVLogger2.d("CloudFunction error: " + e.getMessage());
                    return null;
                }
            }
        });
    }

    /* access modifiers changed from: package-private */
    public <T> Observable<T> executeCachedQuery(String str, Map<String, Object> map, AVQuery.CachePolicy cachePolicy, long j, final QueryExecutor queryExecutor, final QueryExecutor queryExecutor2) {
        int i = AnonymousClass28.$SwitchMap$cn$leancloud$AVQuery$CachePolicy[cachePolicy.ordinal()];
        if (i == 1) {
            return queryExecutor.executor();
        }
        if (i == 2) {
            return queryExecutor.executor().onErrorResumeNext(new Function<Throwable, Observable<T>>() {
                /* class cn.leancloud.core.StorageClient.AnonymousClass22 */

                public Observable<T> apply(Throwable th) throws Exception {
                    AVLogger aVLogger = StorageClient.LOGGER;
                    aVLogger.d("failed to query local cache, cause: " + th.getMessage() + ", try to query networking");
                    return queryExecutor2.executor();
                }
            });
        }
        if (i != 3) {
            return queryExecutor2.executor();
        }
        return queryExecutor2.executor().onErrorResumeNext(new Function<Throwable, Observable<T>>() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass23 */

            public Observable<T> apply(Throwable th) throws Exception {
                AVLogger aVLogger = StorageClient.LOGGER;
                aVLogger.d("failed to query networking, cause: " + th.getMessage() + ", try to query local cache.");
                return queryExecutor.executor();
            }
        });
    }

    public <T> Observable<T> callRPCWithCachePolicy(final String str, final Map<String, Object> map, final AVQuery.CachePolicy cachePolicy, final long j) {
        final String generateCachedKey = QueryResultCache.generateCachedKey(str, map);
        return executeCachedQuery(str, map, cachePolicy, j, new QueryExecutor() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass24 */

            /* JADX DEBUG: Type inference failed for r0v2. Raw type applied. Possible types: io.reactivex.Observable<R>, io.reactivex.Observable<T> */
            @Override // cn.leancloud.core.StorageClient.QueryExecutor
            public <T> Observable<T> executor() {
                return (Observable<R>) QueryResultCache.getInstance().getCacheRawResult(str, generateCachedKey, j, true).map(new Function<String, T>() {
                    /* class cn.leancloud.core.StorageClient.AnonymousClass24.AnonymousClass1 */

                    public T apply(String str) throws Exception {
                        if (StringUtil.isEmpty(str)) {
                            return null;
                        }
                        AVLogger aVLogger = StorageClient.LOGGER;
                        aVLogger.d("found cached rpc result: " + str);
                        T t = (T) JSON.parse(str);
                        return t instanceof Collection ? (T) Utils.getObjectFrom((Collection) t) : t instanceof Map ? (T) Utils.getObjectFrom((Map<String, Object>) t) : t;
                    }
                });
            }
        }, new QueryExecutor() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass25 */

            @Override // cn.leancloud.core.StorageClient.QueryExecutor
            public <T> Observable<T> executor() {
                return StorageClient.this.callRPC(str, map, (cachePolicy == AVQuery.CachePolicy.IGNORE_CACHE || cachePolicy == AVQuery.CachePolicy.NETWORK_ONLY) ? false : true, generateCachedKey);
            }
        });
    }

    public <T> Observable<T> callFunctionWithCachePolicy(final String str, final Map<String, Object> map, final AVQuery.CachePolicy cachePolicy, final long j) {
        final String generateCachedKey = QueryResultCache.generateCachedKey(str, map);
        return executeCachedQuery(str, map, cachePolicy, j, new QueryExecutor() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass26 */

            /* JADX DEBUG: Type inference failed for r0v2. Raw type applied. Possible types: io.reactivex.Observable<R>, io.reactivex.Observable<T> */
            @Override // cn.leancloud.core.StorageClient.QueryExecutor
            public <T> Observable<T> executor() {
                return (Observable<R>) QueryResultCache.getInstance().getCacheRawResult(str, generateCachedKey, j, true).map(new Function<String, T>() {
                    /* class cn.leancloud.core.StorageClient.AnonymousClass26.AnonymousClass1 */

                    public T apply(String str) throws Exception {
                        if (StringUtil.isEmpty(str)) {
                            return null;
                        }
                        AVLogger aVLogger = StorageClient.LOGGER;
                        aVLogger.d("found cached function result: " + str);
                        T t = (T) JSON.parse(str);
                        return t instanceof Collection ? (T) Utils.getObjectFrom((Collection) t) : t instanceof Map ? (T) Utils.getObjectFrom((Map<String, Object>) t) : t;
                    }
                });
            }
        }, new QueryExecutor() {
            /* class cn.leancloud.core.StorageClient.AnonymousClass27 */

            @Override // cn.leancloud.core.StorageClient.QueryExecutor
            public <T> Observable<T> executor() {
                return StorageClient.this.callFunction(str, map, (cachePolicy == AVQuery.CachePolicy.IGNORE_CACHE || cachePolicy == AVQuery.CachePolicy.NETWORK_ONLY) ? false : true, generateCachedKey);
            }
        });
    }

    public Observable<AVCaptchaDigest> requestCaptcha(AVCaptchaOption aVCaptchaOption) {
        return wrapObservable(this.apiService.requestCaptcha(aVCaptchaOption.getRequestParam()));
    }

    public Observable<AVCaptchaValidateResult> verifyCaptcha(String str, String str2) {
        if (StringUtil.isEmpty(str) || StringUtil.isEmpty(str2)) {
            return Observable.error(new IllegalArgumentException("code or token is empty"));
        }
        HashMap hashMap = new HashMap(2);
        hashMap.put("captcha_code", str);
        hashMap.put("captcha_token", str2);
        return wrapObservable(this.apiService.verifyCaptcha(hashMap));
    }

    public Observable<AVNull> requestSMSCode(String str, Map<String, Object> map) {
        map.put(AVUser.ATTR_MOBILEPHONE, str);
        return wrapObservable(this.apiService.requestSMSCode(map));
    }

    public Observable<AVNull> requestSMSCodeForUpdatingPhoneNumber(String str, Map<String, Object> map) {
        map.put(AVUser.ATTR_MOBILEPHONE, str);
        return wrapObservable(this.apiService.requestSMSCodeForUpdatingPhoneNumber(map));
    }

    public Observable<AVNull> verifySMSCode(String str, String str2) {
        if (StringUtil.isEmpty(str) || StringUtil.isEmpty(str2)) {
            return Observable.error(new IllegalArgumentException("code or mobilePhone is empty"));
        }
        HashMap hashMap = new HashMap(1);
        hashMap.put(AVUser.ATTR_MOBILEPHONE, str2);
        return wrapObservable(this.apiService.verifySMSCode(str, hashMap));
    }

    public Observable<AVNull> verifySMSCodeForUpdatingPhoneNumber(String str, String str2) {
        if (StringUtil.isEmpty(str) || StringUtil.isEmpty(str2)) {
            return Observable.error(new IllegalArgumentException("code or mobilePhone is empty"));
        }
        HashMap hashMap = new HashMap(1);
        hashMap.put(AVUser.ATTR_MOBILEPHONE, str2);
        hashMap.put("code", str);
        return wrapObservable(this.apiService.verifySMSCodeForUpdatingPhoneNumber(hashMap));
    }

    public Observable<AVSearchResponse> search(Map<String, String> map) {
        return wrapObservable(this.apiService.search(map));
    }
}
