package com.android.volley.cronet;

import android.content.Context;
import android.text.TextUtils;
import android.util.Base64;
import com.android.volley.AuthFailureError;
import com.android.volley.Header;
import com.android.volley.Request;
import com.android.volley.RequestTask;
import com.android.volley.VolleyLog;
import com.android.volley.toolbox.AsyncHttpStack;
import com.android.volley.toolbox.ByteArrayPool;
import com.android.volley.toolbox.HttpClientStack;
import com.android.volley.toolbox.HttpHeaderParser;
import com.android.volley.toolbox.HttpResponse;
import com.android.volley.toolbox.PoolingByteArrayOutputStream;
import com.android.volley.toolbox.UrlRewriter;
import com.bumptech.glide.load.Key;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.nio.ByteBuffer;
import java.nio.channels.Channels;
import java.nio.channels.WritableByteChannel;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;
import java.util.concurrent.Executor;
import java.util.concurrent.ExecutorService;
import org.chromium.net.CronetEngine;
import org.chromium.net.CronetException;
import org.chromium.net.UploadDataProviders;
import org.chromium.net.UrlRequest;
import org.chromium.net.UrlResponseInfo;

public class CronetHttpStack extends AsyncHttpStack {
    private final CronetEngine mCronetEngine;
    private final CurlCommandLogger mCurlCommandLogger;
    private final boolean mCurlLoggingEnabled;
    private final boolean mLogAuthTokensInCurlCommands;
    private final ByteArrayPool mPool;
    private final RequestListener mRequestListener;
    private final UrlRewriter mUrlRewriter;

    public interface CurlCommandLogger {
        void logCurlCommand(String str);
    }

    private CronetHttpStack(CronetEngine cronetEngine, ByteArrayPool byteArrayPool, UrlRewriter urlRewriter, RequestListener requestListener, boolean z, CurlCommandLogger curlCommandLogger, boolean z2) {
        this.mCronetEngine = cronetEngine;
        this.mPool = byteArrayPool;
        this.mUrlRewriter = urlRewriter;
        this.mRequestListener = requestListener;
        this.mCurlLoggingEnabled = z;
        this.mCurlCommandLogger = curlCommandLogger;
        this.mLogAuthTokensInCurlCommands = z2;
        requestListener.initialize(this);
    }

    @Override // com.android.volley.toolbox.AsyncHttpStack
    public void executeRequest(Request<?> request, Map<String, String> map, final AsyncHttpStack.OnRequestComplete onRequestComplete) {
        if (getBlockingExecutor() == null || getNonBlockingExecutor() == null) {
            throw new IllegalStateException("Must set blocking and non-blocking executors");
        }
        AnonymousClass1 r0 = new UrlRequest.Callback() {
            /* class com.android.volley.cronet.CronetHttpStack.AnonymousClass1 */
            PoolingByteArrayOutputStream bytesReceived = null;
            WritableByteChannel receiveChannel = null;

            public void onRedirectReceived(UrlRequest urlRequest, UrlResponseInfo urlResponseInfo, String str) {
                urlRequest.followRedirect();
            }

            public void onResponseStarted(UrlRequest urlRequest, UrlResponseInfo urlResponseInfo) {
                PoolingByteArrayOutputStream poolingByteArrayOutputStream = new PoolingByteArrayOutputStream(CronetHttpStack.this.mPool, CronetHttpStack.this.getContentLength(urlResponseInfo));
                this.bytesReceived = poolingByteArrayOutputStream;
                this.receiveChannel = Channels.newChannel(poolingByteArrayOutputStream);
                urlRequest.read(ByteBuffer.allocateDirect(1024));
            }

            public void onReadCompleted(UrlRequest urlRequest, UrlResponseInfo urlResponseInfo, ByteBuffer byteBuffer) {
                byteBuffer.flip();
                try {
                    this.receiveChannel.write(byteBuffer);
                    byteBuffer.clear();
                    urlRequest.read(byteBuffer);
                } catch (IOException e) {
                    urlRequest.cancel();
                    onRequestComplete.onError(e);
                }
            }

            public void onSucceeded(UrlRequest urlRequest, UrlResponseInfo urlResponseInfo) {
                onRequestComplete.onSuccess(new HttpResponse(urlResponseInfo.getHttpStatusCode(), CronetHttpStack.getHeaders(urlResponseInfo.getAllHeadersAsList()), this.bytesReceived.toByteArray()));
            }

            public void onFailed(UrlRequest urlRequest, UrlResponseInfo urlResponseInfo, CronetException cronetException) {
                onRequestComplete.onError(cronetException);
            }
        };
        String url = request.getUrl();
        String rewriteUrl = this.mUrlRewriter.rewriteUrl(url);
        if (rewriteUrl == null) {
            onRequestComplete.onError(new IOException("URL blocked by rewriter: " + url));
            return;
        }
        getBlockingExecutor().execute(new SetUpRequestTask(request, rewriteUrl, this.mCronetEngine.newUrlRequestBuilder(rewriteUrl, r0, getNonBlockingExecutor()).allowDirectExecutor().disableCache().setPriority(getPriority(request)), map, onRequestComplete));
    }

    private class SetUpRequestTask<T> extends RequestTask<T> {
        Map<String, String> additionalHeaders;
        UrlRequest.Builder builder;
        AsyncHttpStack.OnRequestComplete callback;
        Request<T> request;
        String url;

        SetUpRequestTask(Request<T> request2, String str, UrlRequest.Builder builder2, Map<String, String> map, AsyncHttpStack.OnRequestComplete onRequestComplete) {
            super(request2);
            this.url = str;
            this.builder = builder2;
            this.additionalHeaders = map;
            this.callback = onRequestComplete;
            this.request = request2;
        }

        public void run() {
            try {
                CronetHttpStack.this.mRequestListener.onRequestPrepared(this.request, this.builder);
                CurlLoggedRequestParameters curlLoggedRequestParameters = new CurlLoggedRequestParameters();
                CronetHttpStack.this.setHttpMethod(curlLoggedRequestParameters, this.request);
                CronetHttpStack.this.setRequestHeaders(curlLoggedRequestParameters, this.request, this.additionalHeaders);
                curlLoggedRequestParameters.applyToRequest(this.builder, CronetHttpStack.this.getNonBlockingExecutor());
                UrlRequest build = this.builder.build();
                if (CronetHttpStack.this.mCurlLoggingEnabled) {
                    CronetHttpStack.this.mCurlCommandLogger.logCurlCommand(CronetHttpStack.this.generateCurlCommand(this.url, curlLoggedRequestParameters));
                }
                build.start();
            } catch (AuthFailureError e) {
                this.callback.onAuthError(e);
            }
        }
    }

    public static List<Header> getHeaders(List<Map.Entry<String, String>> list) {
        ArrayList arrayList = new ArrayList();
        for (Map.Entry<String, String> entry : list) {
            arrayList.add(new Header(entry.getKey(), entry.getValue()));
        }
        return arrayList;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setHttpMethod(CurlLoggedRequestParameters curlLoggedRequestParameters, Request<?> request) throws AuthFailureError {
        switch (request.getMethod()) {
            case -1:
                byte[] postBody = request.getPostBody();
                if (postBody != null) {
                    curlLoggedRequestParameters.setHttpMethod("POST");
                    addBodyIfExists(curlLoggedRequestParameters, request.getPostBodyContentType(), postBody);
                    return;
                }
                curlLoggedRequestParameters.setHttpMethod("GET");
                return;
            case 0:
                curlLoggedRequestParameters.setHttpMethod("GET");
                return;
            case 1:
                curlLoggedRequestParameters.setHttpMethod("POST");
                addBodyIfExists(curlLoggedRequestParameters, request.getBodyContentType(), request.getBody());
                return;
            case 2:
                curlLoggedRequestParameters.setHttpMethod("PUT");
                addBodyIfExists(curlLoggedRequestParameters, request.getBodyContentType(), request.getBody());
                return;
            case 3:
                curlLoggedRequestParameters.setHttpMethod("DELETE");
                return;
            case 4:
                curlLoggedRequestParameters.setHttpMethod("HEAD");
                return;
            case 5:
                curlLoggedRequestParameters.setHttpMethod("OPTIONS");
                return;
            case 6:
                curlLoggedRequestParameters.setHttpMethod("TRACE");
                return;
            case 7:
                curlLoggedRequestParameters.setHttpMethod(HttpClientStack.HttpPatch.METHOD_NAME);
                addBodyIfExists(curlLoggedRequestParameters, request.getBodyContentType(), request.getBody());
                return;
            default:
                throw new IllegalStateException("Unknown method type.");
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setRequestHeaders(CurlLoggedRequestParameters curlLoggedRequestParameters, Request<?> request, Map<String, String> map) throws AuthFailureError {
        curlLoggedRequestParameters.putAllHeaders(map);
        curlLoggedRequestParameters.putAllHeaders(request.getHeaders());
    }

    private void addBodyIfExists(CurlLoggedRequestParameters curlLoggedRequestParameters, String str, byte[] bArr) {
        curlLoggedRequestParameters.setBody(str, bArr);
    }

    /* access modifiers changed from: package-private */
    /* renamed from: com.android.volley.cronet.CronetHttpStack$2  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass2 {
        static final /* synthetic */ int[] $SwitchMap$com$android$volley$Request$Priority;

        /* JADX WARNING: Can't wrap try/catch for region: R(8:0|1|2|3|4|5|6|(3:7|8|10)) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0012 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x001d */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0028 */
        static {
            int[] iArr = new int[Request.Priority.values().length];
            $SwitchMap$com$android$volley$Request$Priority = iArr;
            iArr[Request.Priority.LOW.ordinal()] = 1;
            $SwitchMap$com$android$volley$Request$Priority[Request.Priority.HIGH.ordinal()] = 2;
            $SwitchMap$com$android$volley$Request$Priority[Request.Priority.IMMEDIATE.ordinal()] = 3;
            try {
                $SwitchMap$com$android$volley$Request$Priority[Request.Priority.NORMAL.ordinal()] = 4;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    private int getPriority(Request<?> request) {
        int i = AnonymousClass2.$SwitchMap$com$android$volley$Request$Priority[request.getPriority().ordinal()];
        if (i != 1) {
            return (i == 2 || i == 3) ? 4 : 3;
        }
        return 2;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private int getContentLength(UrlResponseInfo urlResponseInfo) {
        List list = (List) urlResponseInfo.getAllHeaders().get("Content-Length");
        if (list == null) {
            return 1024;
        }
        return Integer.parseInt((String) list.get(0));
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String generateCurlCommand(String str, CurlLoggedRequestParameters curlLoggedRequestParameters) {
        StringBuilder sb = new StringBuilder("curl ");
        sb.append("-X ");
        sb.append(curlLoggedRequestParameters.getHttpMethod());
        sb.append(" ");
        for (Map.Entry<String, String> entry : curlLoggedRequestParameters.getHeaders().entrySet()) {
            sb.append("--header \"");
            sb.append(entry.getKey());
            sb.append(": ");
            if (this.mLogAuthTokensInCurlCommands || (!"Authorization".equals(entry.getKey()) && !"Cookie".equals(entry.getKey()))) {
                sb.append(entry.getValue());
            } else {
                sb.append("[REDACTED]");
            }
            sb.append("\" ");
        }
        sb.append("\"");
        sb.append(str);
        sb.append("\"");
        if (curlLoggedRequestParameters.getBody() != null) {
            if (curlLoggedRequestParameters.getBody().length >= 1024) {
                sb.append(" [REQUEST BODY TOO LARGE TO INCLUDE]");
            } else if (isBinaryContentForLogging(curlLoggedRequestParameters)) {
                String encodeToString = Base64.encodeToString(curlLoggedRequestParameters.getBody(), 2);
                sb.insert(0, "echo '" + encodeToString + "' | base64 -d > /tmp/$$.bin; ").append(" --data-binary @/tmp/$$.bin");
            } else {
                try {
                    sb.append(" --data-ascii \"");
                    sb.append(new String(curlLoggedRequestParameters.getBody(), Key.STRING_CHARSET_NAME));
                    sb.append("\"");
                } catch (UnsupportedEncodingException e) {
                    throw new RuntimeException("Could not encode to UTF-8", e);
                }
            }
        }
        return sb.toString();
    }

    private boolean isBinaryContentForLogging(CurlLoggedRequestParameters curlLoggedRequestParameters) {
        String str = curlLoggedRequestParameters.getHeaders().get("Content-Encoding");
        if (str != null) {
            for (String str2 : TextUtils.split(str, ",")) {
                if ("gzip".equals(str2.trim())) {
                    return true;
                }
            }
        }
        String str3 = curlLoggedRequestParameters.getHeaders().get(HttpHeaderParser.HEADER_CONTENT_TYPE);
        if (str3 == null) {
            return true;
        }
        if (str3.startsWith("text/") || str3.startsWith("application/xml") || str3.startsWith("application/json")) {
            return false;
        }
        return true;
    }

    public static class Builder {
        private static final int DEFAULT_POOL_SIZE = 4096;
        private final Context context;
        private CronetEngine mCronetEngine;
        private CurlCommandLogger mCurlCommandLogger;
        private boolean mCurlLoggingEnabled;
        private boolean mLogAuthTokensInCurlCommands;
        private ByteArrayPool mPool;
        private RequestListener mRequestListener;
        private UrlRewriter mUrlRewriter;

        public Builder(Context context2) {
            this.context = context2;
        }

        public Builder setCronetEngine(CronetEngine cronetEngine) {
            this.mCronetEngine = cronetEngine;
            return this;
        }

        public Builder setPool(ByteArrayPool byteArrayPool) {
            this.mPool = byteArrayPool;
            return this;
        }

        public Builder setUrlRewriter(UrlRewriter urlRewriter) {
            this.mUrlRewriter = urlRewriter;
            return this;
        }

        public Builder setRequestListener(RequestListener requestListener) {
            this.mRequestListener = requestListener;
            return this;
        }

        public Builder setCurlLoggingEnabled(boolean z) {
            this.mCurlLoggingEnabled = z;
            return this;
        }

        public Builder setCurlCommandLogger(CurlCommandLogger curlCommandLogger) {
            this.mCurlCommandLogger = curlCommandLogger;
            return this;
        }

        public Builder setLogAuthTokensInCurlCommands(boolean z) {
            this.mLogAuthTokensInCurlCommands = z;
            return this;
        }

        public CronetHttpStack build() {
            if (this.mCronetEngine == null) {
                this.mCronetEngine = new CronetEngine.Builder(this.context).build();
            }
            if (this.mUrlRewriter == null) {
                this.mUrlRewriter = new UrlRewriter() {
                    /* class com.android.volley.cronet.CronetHttpStack.Builder.AnonymousClass1 */

                    @Override // com.android.volley.toolbox.UrlRewriter
                    public String rewriteUrl(String str) {
                        return str;
                    }
                };
            }
            if (this.mRequestListener == null) {
                this.mRequestListener = new RequestListener() {
                    /* class com.android.volley.cronet.CronetHttpStack.Builder.AnonymousClass2 */
                };
            }
            if (this.mPool == null) {
                this.mPool = new ByteArrayPool(4096);
            }
            if (this.mCurlCommandLogger == null) {
                this.mCurlCommandLogger = new CurlCommandLogger() {
                    /* class com.android.volley.cronet.CronetHttpStack.Builder.AnonymousClass3 */

                    @Override // com.android.volley.cronet.CronetHttpStack.CurlCommandLogger
                    public void logCurlCommand(String str) {
                        VolleyLog.v(str, new Object[0]);
                    }
                };
            }
            return new CronetHttpStack(this.mCronetEngine, this.mPool, this.mUrlRewriter, this.mRequestListener, this.mCurlLoggingEnabled, this.mCurlCommandLogger, this.mLogAuthTokensInCurlCommands);
        }
    }

    public static abstract class RequestListener {
        private CronetHttpStack mStack;

        public void onRequestPrepared(Request<?> request, UrlRequest.Builder builder) {
        }

        /* access modifiers changed from: package-private */
        public void initialize(CronetHttpStack cronetHttpStack) {
            this.mStack = cronetHttpStack;
        }

        /* access modifiers changed from: protected */
        public Executor getNonBlockingExecutor() {
            return this.mStack.getNonBlockingExecutor();
        }

        /* access modifiers changed from: protected */
        public Executor getBlockingExecutor() {
            return this.mStack.getBlockingExecutor();
        }
    }

    /* access modifiers changed from: private */
    public static class CurlLoggedRequestParameters {
        private byte[] mBody;
        private final TreeMap<String, String> mHeaders;
        private String mHttpMethod;

        private CurlLoggedRequestParameters() {
            this.mHeaders = new TreeMap<>(String.CASE_INSENSITIVE_ORDER);
        }

        /* access modifiers changed from: package-private */
        public TreeMap<String, String> getHeaders() {
            return this.mHeaders;
        }

        /* access modifiers changed from: package-private */
        public void putAllHeaders(Map<String, String> map) {
            this.mHeaders.putAll(map);
        }

        /* access modifiers changed from: package-private */
        public String getHttpMethod() {
            return this.mHttpMethod;
        }

        /* access modifiers changed from: package-private */
        public void setHttpMethod(String str) {
            this.mHttpMethod = str;
        }

        /* access modifiers changed from: package-private */
        public byte[] getBody() {
            return this.mBody;
        }

        /* access modifiers changed from: package-private */
        public void setBody(String str, byte[] bArr) {
            this.mBody = bArr;
            if (bArr != null && !this.mHeaders.containsKey(HttpHeaderParser.HEADER_CONTENT_TYPE)) {
                this.mHeaders.put(HttpHeaderParser.HEADER_CONTENT_TYPE, str);
            }
        }

        /* access modifiers changed from: package-private */
        public void applyToRequest(UrlRequest.Builder builder, ExecutorService executorService) {
            for (Map.Entry<String, String> entry : this.mHeaders.entrySet()) {
                builder.addHeader(entry.getKey(), entry.getValue());
            }
            builder.setHttpMethod(this.mHttpMethod);
            byte[] bArr = this.mBody;
            if (bArr != null) {
                builder.setUploadDataProvider(UploadDataProviders.create(bArr), executorService);
            }
        }
    }
}
